@@ -16,8 +16,6 @@ dependencies {
     testImplementation(libs.assertj)
 
     testFixturesApi(libs.kotlin.stdlibJdk8)
-
-    dokkaJekyllPlugin(libs.dokka.jekyll)
 }
 
 val javaComponent = components["java"] as AdhocComponentWithVariants
@@ -30,10 +28,10 @@ listOf(configurations.testFixturesApiElements, configurations.testFixturesRuntim
 }
 
 tasks.withType<DokkaTask>().configureEach {
-    outputDirectory.set(rootDir.resolve("docs/pages/kdoc"))
+    outputDirectory.set(rootDir.resolve("website/static/kdoc"))
 }
 
-tasks.dokkaJekyll {
+tasks.dokkaHtml {
     notCompatibleWithConfigurationCache("https://github.com/Kotlin/dokka/issues/1217")
 }
 
