@@ -1,10 +1,10 @@
 package io.gitlab.arturbosch.detekt.api
 
 import io.github.detekt.psi.FilePath
+import io.github.detekt.psi.getLineAndColumnInPsiFile
 import io.github.detekt.psi.toFilePath
 import org.jetbrains.kotlin.com.intellij.openapi.util.TextRange
 import org.jetbrains.kotlin.com.intellij.psi.PsiElement
-import org.jetbrains.kotlin.diagnostics.DiagnosticUtils
 import org.jetbrains.kotlin.diagnostics.PsiDiagnosticUtils
 import org.jetbrains.kotlin.psi.KtFile
 import org.jetbrains.kotlin.psi.psiUtil.endOffset
@@ -14,7 +14,10 @@ import java.nio.file.Paths
 /**
  * Specifies a position within a source code fragment.
  */
-data class Location @Deprecated("Consider relative path by passing a [FilePath]") @JvmOverloads constructor(
+data class Location
+@Deprecated("Consider relative path by passing a [FilePath]")
+@JvmOverloads
+constructor(
     val source: SourceLocation,
     val text: TextLocation,
     @Deprecated(
@@ -48,10 +51,7 @@ data class Location @Deprecated("Consider relative path by passing a [FilePath]"
 
     @Suppress("DEPRECATION")
     @Deprecated(
-        """
-        locationString was removed and won't get passed to the main constructor.
-        Use queries on 'ktElement' instead.
-        """,
+        "locationString was removed and won't get passed to the main constructor. Use queries on 'ktElement' instead.",
         ReplaceWith(
             "Location(source, text, file)",
             "io.gitlab.arturbosch.detekt.api.Location"
@@ -99,12 +99,8 @@ data class Location @Deprecated("Consider relative path by passing a [FilePath]"
             )
 
         private fun lineAndColumn(element: PsiElement, range: TextRange): PsiDiagnosticUtils.LineAndColumn {
-            return try {
-                DiagnosticUtils.getLineAndColumnInPsiFile(element.containingFile, range)
-            } catch (@Suppress("SwallowedException", "TooGenericExceptionCaught") e: IndexOutOfBoundsException) {
-                // #3317 If any rule mutates the PsiElement, searching the original PsiElement may throw exception.
-                PsiDiagnosticUtils.LineAndColumn(-1, -1, null)
-            }
+            return getLineAndColumnInPsiFile(element.containingFile, range)
+                ?: PsiDiagnosticUtils.LineAndColumn(-1, -1, null)
         }
     }
 }
