@@ -6,11 +6,11 @@ import io.gitlab.arturbosch.detekt.api.BaseRule
 import io.gitlab.arturbosch.detekt.api.Config
 import io.gitlab.arturbosch.detekt.api.FileProcessListener
 import io.gitlab.arturbosch.detekt.api.Finding
-import io.gitlab.arturbosch.detekt.api.MultiRule
 import io.gitlab.arturbosch.detekt.api.Rule
 import io.gitlab.arturbosch.detekt.api.RuleSetId
 import io.gitlab.arturbosch.detekt.api.RuleSetProvider
 import io.gitlab.arturbosch.detekt.api.internal.CompilerResources
+import io.gitlab.arturbosch.detekt.api.internal.RequiresTypeResolution
 import io.gitlab.arturbosch.detekt.api.internal.whichDetekt
 import io.gitlab.arturbosch.detekt.api.internal.whichJava
 import io.gitlab.arturbosch.detekt.api.internal.whichOS
@@ -25,6 +25,7 @@ import org.jetbrains.kotlin.config.languageVersionSettings
 import org.jetbrains.kotlin.psi.KtFile
 import org.jetbrains.kotlin.resolve.BindingContext
 import org.jetbrains.kotlin.resolve.calls.smartcasts.DataFlowValueFactoryImpl
+import kotlin.reflect.full.hasAnnotation
 
 private typealias FindingsResult = List<Map<RuleSetId, List<Finding>>>
 
@@ -42,7 +43,6 @@ internal class Analyzer(
     ): Map<RuleSetId, List<Finding>> {
         val languageVersionSettings = settings.environment.configuration.languageVersionSettings
 
-        @Suppress("DEPRECATION")
         val dataFlowValueFactory = DataFlowValueFactoryImpl(languageVersionSettings)
         val compilerResources = CompilerResources(languageVersionSettings, dataFlowValueFactory)
         val findingsPerFile: FindingsResult =
@@ -52,6 +52,10 @@ internal class Analyzer(
                 runSync(ktFiles, bindingContext, compilerResources)
             }
 
+        if (bindingContext == BindingContext.EMPTY) {
+            warnAboutEnabledRequiresTypeResolutionRules()
+        }
+
         val findingsPerRuleSet = HashMap<RuleSetId, List<Finding>>()
         for (findings in findingsPerFile) {
             findingsPerRuleSet.mergeSmells(findings)
@@ -95,9 +99,10 @@ internal class Analyzer(
         bindingContext: BindingContext,
         compilerResources: CompilerResources
     ): Map<RuleSetId, List<Finding>> {
+        @Suppress("DEPRECATION")
         fun isCorrectable(rule: BaseRule): Boolean = when (rule) {
             is Rule -> rule.autoCorrect
-            is MultiRule -> rule.rules.any { it.autoCorrect }
+            is io.gitlab.arturbosch.detekt.api.MultiRule -> rule.rules.any { it.autoCorrect }
             else -> error("No other rule type expected.")
         }
 
@@ -113,6 +118,9 @@ internal class Analyzer(
 
         val (correctableRules, otherRules) = activeRuleSetsToRuleSetConfigs
             .flatMap { (ruleSet, _) -> ruleSet.rules.asSequence() }
+            .filter { rule ->
+                bindingContext != BindingContext.EMPTY || !rule::class.hasAnnotation<RequiresTypeResolution>()
+            }
             .partition { isCorrectable(it) }
 
         val result = HashMap<RuleSetId, MutableList<Finding>>()
@@ -135,6 +143,19 @@ internal class Analyzer(
 
         return result
     }
+
+    private fun warnAboutEnabledRequiresTypeResolutionRules() {
+        providers.asSequence()
+            .map { it to config.subConfig(it.ruleSetId) }
+            .filter { (_, ruleSetConfig) -> ruleSetConfig.isActive() }
+            .map { (provider, ruleSetConfig) -> provider.instance(ruleSetConfig) to ruleSetConfig }
+            .flatMap { (ruleSet, _) -> ruleSet.rules.asSequence() }
+            .filter { rule -> (rule as? Rule)?.active == true }
+            .filter { rule -> rule::class.hasAnnotation<RequiresTypeResolution>() }
+            .forEach { rule ->
+                settings.debug { "The rule '${rule.ruleId}' requires type resolution but it was run without it." }
+            }
+    }
 }
 
 private fun filterSuppressedFindings(rule: BaseRule, bindingContext: BindingContext): List<Finding> {
@@ -154,11 +175,11 @@ private fun MutableMap<String, List<Finding>>.mergeSmells(other: Map<String, Lis
 
 private fun throwIllegalStateException(file: KtFile, error: Throwable): Nothing {
     val message = """
-    Analyzing ${file.absolutePath()} led to an exception. 
-    Location: ${error.stackTrace.firstOrNull()?.toString()}
-    The original exception message was: ${error.localizedMessage}
-    Running detekt '${whichDetekt() ?: "unknown"}' on Java '${whichJava()}' on OS '${whichOS()}'
-    If the exception message does not help, please feel free to create an issue on our GitHub page.
+        Analyzing ${file.absolutePath()} led to an exception.
+        Location: ${error.stackTrace.firstOrNull()?.toString()}
+        The original exception message was: ${error.localizedMessage}
+        Running detekt '${whichDetekt() ?: "unknown"}' on Java '${whichJava()}' on OS '${whichOS()}'
+        If the exception message does not help, please feel free to create an issue on our GitHub page.
     """.trimIndent()
     throw IllegalStateException(message, error)
 }
