@@ -18,7 +18,6 @@ internal fun generateBindingContext(
     classpath: List<String>,
     files: List<KtFile>,
     debugPrinter: (() -> String) -> Unit,
-    warningPrinter: (String) -> Unit,
 ): BindingContext {
     if (classpath.isEmpty()) {
         return BindingContext.EMPTY
@@ -27,12 +26,12 @@ internal fun generateBindingContext(
     val messageCollector = DetektMessageCollector(
         minSeverity = CompilerMessageSeverity.ERROR,
         debugPrinter = debugPrinter,
-        warningPrinter = warningPrinter,
     )
 
     val analyzer = AnalyzerWithCompilerReport(
         messageCollector,
         environment.configuration.languageVersionSettings,
+        false,
     )
     analyzer.analyzeAndReport(files) {
         TopDownAnalyzerFacadeForJVM.analyzeFilesWithJavaIntegration(
@@ -45,15 +44,12 @@ internal fun generateBindingContext(
         )
     }
 
-    messageCollector.printIssuesCountIfAny()
-
     return analyzer.analysisResult.bindingContext
 }
 
 internal class DetektMessageCollector(
     private val minSeverity: CompilerMessageSeverity,
     private val debugPrinter: (() -> String) -> Unit,
-    private val warningPrinter: (String) -> Unit,
 ) : MessageCollector by MessageCollector.NONE {
     private var messages = 0
 
@@ -63,15 +59,6 @@ internal class DetektMessageCollector(
             messages++
         }
     }
-
-    fun printIssuesCountIfAny() {
-        if (messages > 0) {
-            warningPrinter(
-                "The BindingContext was created with $messages issues. " +
-                    "Run detekt with --debug to see the error messages."
-            )
-        }
-    }
 }
 
 private object DetektMessageRenderer : PlainTextMessageRenderer() {
