@@ -9,7 +9,6 @@ import io.gitlab.arturbosch.detekt.api.Debt
 import io.gitlab.arturbosch.detekt.api.Entity
 import io.gitlab.arturbosch.detekt.api.Issue
 import io.gitlab.arturbosch.detekt.api.Location
-import io.gitlab.arturbosch.detekt.api.MultiRule
 import io.gitlab.arturbosch.detekt.api.Rule
 import io.gitlab.arturbosch.detekt.api.RuleSet
 import io.gitlab.arturbosch.detekt.api.Severity
@@ -170,7 +169,7 @@ class SuppressionSpec {
                     println("FAILED TEST")
                 }
             }
-                """
+                """.trimIndent()
             )
             val rule = TestRule()
             rule.visitFile(ktFile)
@@ -188,7 +187,7 @@ class SuppressionSpec {
                     println("FAILED TEST")
                 }
             }
-                """
+                """.trimIndent()
             )
             val rule = TestRule()
             rule.visitFile(ktFile)
@@ -206,7 +205,7 @@ class SuppressionSpec {
                     println("FAILED TEST")
                 }
             }
-                """
+                """.trimIndent()
             )
             val rule = TestRule()
             rule.visitFile(ktFile)
@@ -228,7 +227,7 @@ class SuppressionSpec {
                     println("FAILED TEST")
                 }
             }
-                """
+                """.trimIndent()
             )
             val rule = TestRule(TestConfig(mutableMapOf("aliases" to "[MyTest]")))
             rule.visitFile(ktFile)
@@ -283,6 +282,7 @@ class SuppressionSpec {
         @Nested
         inner class `MultiRule` {
 
+            @Suppress("DEPRECATION")
             private lateinit var subject: io.gitlab.arturbosch.detekt.api.MultiRule
 
             @BeforeEach
@@ -314,13 +314,15 @@ private fun isSuppressedBy(annotation: String, argument: String): Boolean {
     val annotated = """
             @$annotation("$argument")
             class Test
-    """
+    """.trimIndent()
     val file = compileContentForTest(annotated)
     val annotatedClass = file.children.first { it is KtClass } as KtAnnotated
     return annotatedClass.isSuppressedBy("Test", setOf("alias"))
 }
 
-private class AMultiRule(config: Config) : MultiRule() {
+private class AMultiRule(config: Config) :
+    @Suppress("DEPRECATION")
+    io.gitlab.arturbosch.detekt.api.MultiRule() {
     override val rules: List<Rule> = listOf(TestLPL(config))
 }
 
