@@ -1,14 +1,16 @@
 package io.gitlab.arturbosch.detekt.formatting.wrappers
 
-import com.pinterest.ktlint.ruleset.experimental.MultiLineIfElseRule
+import com.pinterest.ktlint.ruleset.standard.MultiLineIfElseRule
 import io.gitlab.arturbosch.detekt.api.Config
+import io.gitlab.arturbosch.detekt.api.internal.ActiveByDefault
 import io.gitlab.arturbosch.detekt.api.internal.AutoCorrectable
 import io.gitlab.arturbosch.detekt.formatting.FormattingRule
 
 /**
- * See [ktlint-readme](https://github.com/pinterest/ktlint#standard-rules) for documentation.
+ * See [ktlint docs](https://pinterest.github.io/ktlint/rules/standard/#multiline-if-else) for documentation.
  */
 @AutoCorrectable(since = "1.0.0")
+@ActiveByDefault(since = "1.22.0")
 class MultiLineIfElse(config: Config) : FormattingRule(config) {
 
     override val wrapping = MultiLineIfElseRule()
