@@ -1,14 +1,17 @@
 package io.gitlab.arturbosch.detekt.formatting.wrappers
 
-import com.pinterest.ktlint.ruleset.experimental.SpacingBetweenDeclarationsWithAnnotationsRule
+import com.pinterest.ktlint.ruleset.standard.SpacingBetweenDeclarationsWithAnnotationsRule
 import io.gitlab.arturbosch.detekt.api.Config
+import io.gitlab.arturbosch.detekt.api.internal.ActiveByDefault
 import io.gitlab.arturbosch.detekt.api.internal.AutoCorrectable
 import io.gitlab.arturbosch.detekt.formatting.FormattingRule
 
 /**
- * See [ktlint-readme](https://github.com/pinterest/ktlint#spacing) for documentation.
+ * See [ktlint docs](https://pinterest.github.io/ktlint/rules/standard/#blank-line-between-declarations-with-annotations)
+ * for documentation.
  */
 @AutoCorrectable(since = "1.10.0")
+@ActiveByDefault(since = "1.22.0")
 class SpacingBetweenDeclarationsWithAnnotations(config: Config) : FormattingRule(config) {
 
     override val wrapping = SpacingBetweenDeclarationsWithAnnotationsRule()
