@@ -17,21 +17,20 @@ class WrappingSpec {
 
     @Test
     fun `Given a wrong wrapping in the class definition`() {
-        val code =
-            """
+        val code = """
             class A() : B, 
                 C {
             }
-            
+
             interface B
 
             interface C
 
-            """.trimIndent()
+        """.trimIndent()
 
         subject.lint(code).assert()
             .hasSize(1)
-            .hasSourceLocation(1, 12)
+            .hasStartSourceLocation(1, 12)
             .hasTextLocations(11 to 12)
     }
 }
