@@ -1,9 +1,10 @@
-import java.io.ByteArrayOutputStream
-
 plugins {
+    alias(libs.plugins.shadow)
     id("module")
 }
 
+tasks.build { finalizedBy(tasks.shadowJar) }
+
 dependencies {
     implementation(projects.detektParser)
     implementation(projects.detektApi)
@@ -24,6 +25,9 @@ val configDir = "${rootProject.rootDir}/detekt-core/src/main/resources"
 val cliOptionsFile = "${rootProject.rootDir}/website/docs/gettingstarted/_cli-options.md"
 val defaultConfigFile = "$configDir/default-detekt-config.yml"
 val deprecationFile = "$configDir/deprecation.properties"
+val formattingConfigFile = "${rootProject.rootDir}/detekt-formatting/src/main/resources/config/config.yml"
+val librariesConfigFile = "${rootProject.rootDir}/detekt-rules-libraries/src/main/resources/config/config.yml"
+val ruleauthorsConfigFile = "${rootProject.rootDir}/detekt-rules-ruleauthors/src/main/resources/config/config.yml"
 
 val ruleModules = rootProject.subprojects
     .filter { "rules" in it.name }
@@ -32,12 +36,20 @@ val ruleModules = rootProject.subprojects
     .map { "${rootProject.rootDir}/$it/src/main/kotlin" }
 
 val generateDocumentation by tasks.registering(JavaExec::class) {
-    dependsOn(tasks.assemble, ":detekt-api:dokkaHtml")
+    dependsOn(
+        tasks.assemble,
+        tasks.shadowJar,
+        ":detekt-api:dokkaHtml",
+        ":detekt-rules-libraries:sourcesJar",
+        ":detekt-rules-ruleauthors:sourcesJar",
+    )
     description = "Generates detekt documentation and the default config.yml based on Rule KDoc"
     group = "documentation"
 
     inputs.files(
         ruleModules.map { fileTree(it) },
+        fileTree("${rootProject.rootDir}/detekt-rules-libraries/src/main/kotlin"),
+        fileTree("${rootProject.rootDir}/detekt-rules-ruleauthors/src/main/kotlin"),
         fileTree("${rootProject.rootDir}/detekt-formatting/src/main/kotlin"),
         file("${rootProject.rootDir}/detekt-generator/build/libs/detekt-generator-${Versions.DETEKT}-all.jar"),
     )
@@ -45,6 +57,9 @@ val generateDocumentation by tasks.registering(JavaExec::class) {
     outputs.files(
         fileTree(documentationDir),
         file(defaultConfigFile),
+        file(formattingConfigFile),
+        file(librariesConfigFile),
+        file(ruleauthorsConfigFile),
         file(deprecationFile),
         file(cliOptionsFile),
     )
@@ -57,7 +72,11 @@ val generateDocumentation by tasks.registering(JavaExec::class) {
     mainClass.set("io.gitlab.arturbosch.detekt.generator.Main")
     args = listOf(
         "--input",
-        ruleModules.plus("${rootProject.rootDir}/detekt-formatting/src/main/kotlin").joinToString(","),
+        ruleModules
+            .plus("${rootProject.rootDir}/detekt-rules-libraries/src/main/kotlin")
+            .plus("${rootProject.rootDir}/detekt-rules-ruleauthors/src/main/kotlin")
+            .plus("${rootProject.rootDir}/detekt-formatting/src/main/kotlin")
+            .joinToString(","),
         "--documentation",
         documentationDir,
         "--config",
@@ -68,20 +87,26 @@ val generateDocumentation by tasks.registering(JavaExec::class) {
 }
 
 val verifyGeneratorOutput by tasks.registering(Exec::class) {
-    notCompatibleWithConfigurationCache("cannot serialize object of type java.io.ByteArrayOutputStream")
     dependsOn(generateDocumentation)
-    description = "Verifies that the default-detekt-config.yml is up-to-date"
-    val configDiff = ByteArrayOutputStream()
-
-    commandLine = listOf("git", "diff", defaultConfigFile, deprecationFile)
-    standardOutput = configDiff
+    description = "Verifies that generated config files are up-to-date"
+    commandLine = listOf(
+        "git",
+        "diff",
+        "--quiet",
+        defaultConfigFile,
+        formattingConfigFile,
+        librariesConfigFile,
+        ruleauthorsConfigFile,
+        deprecationFile,
+    )
+    isIgnoreExitValue = true
 
     doLast {
-        if (configDiff.toString().isNotEmpty()) {
+        if (executionResult.get().exitValue == 1) {
             throw GradleException(
-                "The default-detekt-config.yml is not up-to-date. " +
+                "At least one generated configuration file is not up-to-date. " +
                     "You can execute the generateDocumentation Gradle task " +
-                    "to update it and commit the changed files."
+                    "to update generated files then commit the changes."
             )
         }
     }
