@@ -17,6 +17,11 @@ fun main(args: Array<String>) {
         exitProcess(0)
     }
 
+    if (options.generateCustomRuleConfig) {
+        Generator(options).executeCustomRuleConfig()
+        return
+    }
+
     require(Files.isDirectory(options.documentationPath)) { "Documentation path must be a directory." }
     require(Files.isDirectory(options.configPath)) { "Config path must be a directory." }
 
