@@ -10,10 +10,10 @@ class DeprecatedPrinterSpec {
     fun `prints the correct properties`() {
         val markdownString = DeprecatedPrinter.print(listOf(createRuleSetPage()))
         val expectedMarkdownString = """
-            style>WildcardImport>conf2=use conf1 instead
-            style>WildcardImport>conf4=use conf3 instead
-            
-        """.trimIndent()
+            style>MagicNumber>conf2=use conf1 instead
+            style>MagicNumber>conf4=use conf3 instead
+            style>DuplicateCaseInWhenExpression=is deprecated
+        """.trimIndent() + "\n${writeMigratedRules()}\n"
         assertThat(markdownString).isEqualTo(expectedMarkdownString)
     }
 }
