@@ -5,8 +5,8 @@ plugins {
     idea
     alias(libs.plugins.pluginPublishing)
     // We use this published version of the Detekt plugin to self analyse this project.
-    id("io.gitlab.arturbosch.detekt") version "1.20.0"
-    id("org.gradle.test-retry") version "1.4.0"
+    id("io.gitlab.arturbosch.detekt") version "1.22.0"
+    id("org.gradle.test-retry") version "1.4.1"
 }
 
 repositories {
@@ -59,6 +59,10 @@ val functionalTestImplementation: Configuration by configurations.getting
 
 configurations.compileOnly { extendsFrom(pluginCompileOnly) }
 
+pluginCompileOnly.attributes {
+    attribute(Category.CATEGORY_ATTRIBUTE, objects.named(Category::class.java, "library"))
+}
+
 dependencies {
     compileOnly(libs.kotlin.gradlePluginApi)
     implementation(libs.sarif4k)
@@ -71,7 +75,7 @@ dependencies {
     pluginCompileOnly(libs.kotlin.gradle)
 
     // We use this published version of the detekt-formatting to self analyse this project.
-    detektPlugins("io.gitlab.arturbosch.detekt:detekt-formatting:1.20.0")
+    detektPlugins("io.gitlab.arturbosch.detekt:detekt-formatting:1.22.0")
 }
 
 gradlePlugin {
@@ -134,6 +138,10 @@ tasks {
     ideaModule {
         notCompatibleWithConfigurationCache("https://github.com/gradle/gradle/issues/13480")
     }
+
+    publishPlugins {
+        notCompatibleWithConfigurationCache("https://github.com/gradle/gradle/issues/21283")
+    }
 }
 
 // Skip publishing of test fixture API & runtime variants
@@ -146,6 +154,18 @@ tasks.withType<Sign>().configureEach {
     notCompatibleWithConfigurationCache("https://github.com/gradle/gradle/issues/13470")
 }
 
+tasks.withType<org.jetbrains.kotlin.gradle.tasks.KotlinCompile>().configureEach {
+    kotlinOptions {
+        apiVersion = "1.4"
+        freeCompilerArgs += listOf(
+            "-Xsuppress-version-warnings",
+        )
+        // Note: Currently there are warnings for detekt-gradle-plugin that seemingly can't be fixed
+        //       until Gradle releases an update (https://github.com/gradle/gradle/issues/16345)
+        allWarningsAsErrors = false
+    }
+}
+
 afterEvaluate {
     publishing {
         publications.filterIsInstance<MavenPublication>().forEach {
@@ -175,8 +195,6 @@ afterEvaluate {
     }
 }
 
-val String.byProperty: String? get() = findProperty(this) as? String
-
 tasks.withType<Test>().configureEach {
     retry {
         @Suppress("MagicNumber")
