@@ -78,13 +78,23 @@ class DetektAndroidSpec {
         @DisplayName("task :app:detektTest")
         fun appDetektTest() {
             gradleRunner.runTasksAndCheckResult(":app:detektTest") { buildResult ->
-                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-releaseUnitTest.xml """)
-                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-debugUnitTest.xml """)
-                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-debugAndroidTest.xml """)
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-releaseUnitTest.xml """
+                )
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-debugUnitTest.xml """
+                )
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-debugAndroidTest.xml """
+                )
                 assertThat(buildResult.output).containsPattern("""--input \S*[/\\]app[/\\]src[/\\]test[/\\]java""")
-                assertThat(buildResult.output).containsPattern("""--input \S*[/\\]app[/\\]src[/\\]androidTest[/\\]java""")
+                assertThat(buildResult.output).containsPattern(
+                    """--input \S*[/\\]app[/\\]src[/\\]androidTest[/\\]java"""
+                )
                 assertThat(buildResult.output).containsPattern("""--input \S*[/\\]app[/\\]src[/\\]test[/\\]kotlin""")
-                assertThat(buildResult.output).containsPattern("""--input \S*[/\\]app[/\\]src[/\\]androidTest[/\\]kotlin""")
+                assertThat(buildResult.output).containsPattern(
+                    """--input \S*[/\\]app[/\\]src[/\\]androidTest[/\\]kotlin"""
+                )
                 assertThat(buildResult.output).contains("--report xml:")
                 assertThat(buildResult.output).contains("--report sarif:")
                 assertThat(buildResult.output).doesNotContain("--report txt:")
@@ -128,7 +138,7 @@ class DetektAndroidSpec {
         @DisplayName("task :app:detektMain")
         fun appDetektMain() {
             gradleRunner.runTasksAndExpectFailure(":app:detektMain") { result ->
-                assertThat(result.output).contains("Task 'detektMain' not found in project")
+                assertThat(result.output).containsIgnoringCase("Task 'detektMain' not found in project")
             }
         }
 
@@ -136,7 +146,7 @@ class DetektAndroidSpec {
         @DisplayName("task :app:detektTest")
         fun appDetektTest() {
             gradleRunner.runTasksAndExpectFailure(":app:detektTest") { result ->
-                assertThat(result.output).contains("Task 'detektTest' not found in project")
+                assertThat(result.output).containsIgnoringCase("Task 'detektTest' not found in project")
             }
         }
     }
@@ -190,9 +200,15 @@ class DetektAndroidSpec {
         @DisplayName("task :lib:detektTest")
         fun libDetektTest() {
             gradleRunner.runTasksAndCheckResult(":lib:detektTest") { buildResult ->
-                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-releaseUnitTest.xml """)
-                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-debugUnitTest.xml """)
-                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-debugAndroidTest.xml """)
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-releaseUnitTest.xml """
+                )
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-debugUnitTest.xml """
+                )
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-debugAndroidTest.xml """
+                )
                 assertThat(buildResult.output).contains("--report xml:")
                 assertThat(buildResult.output).contains("--report sarif:")
                 assertThat(buildResult.output).doesNotContain("--report txt:")
@@ -206,6 +222,102 @@ class DetektAndroidSpec {
         }
     }
 
+    @Nested
+    inner class `android library depends on kotlin only library with configuration cache turned on` {
+        val projectLayout = ProjectLayout(numberOfSourceFilesInRootPerSourceDir = 0).apply {
+            addSubmodule(
+                name = "kotlin_only_lib",
+                numberOfSourceFilesPerSourceDir = 1,
+                numberOfCodeSmells = 1,
+                buildFileContent = """
+                    $KOTLIN_ONLY_LIB_PLUGIN_BLOCK
+                    $DETEKT_REPORTS_BLOCK
+                """.trimIndent(),
+                srcDirs = listOf("src/main/java", "src/debug/java", "src/test/java", "src/androidTest/java"),
+                baselineFiles = listOf(
+                    "detekt-baseline.xml",
+                    "detekt-baseline-release.xml",
+                    "detekt-baseline-debug.xml",
+                    "detekt-baseline-releaseUnitTest.xml",
+                    "detekt-baseline-debugUnitTest.xml",
+                    "detekt-baseline-debugAndroidTest.xml"
+                )
+            )
+            addSubmodule(
+                name = "android_lib",
+                numberOfSourceFilesPerSourceDir = 1,
+                numberOfCodeSmells = 1,
+                buildFileContent = """
+                    $LIB_PLUGIN_BLOCK
+                    $ANDROID_BLOCK
+                    $DETEKT_REPORTS_BLOCK
+                    
+                    dependencies {
+                        implementation(project(":kotlin_only_lib"))
+                    }
+                """.trimIndent(),
+                srcDirs = listOf("src/main/java", "src/debug/java", "src/test/java", "src/androidTest/java"),
+                baselineFiles = listOf(
+                    "detekt-baseline.xml",
+                    "detekt-baseline-release.xml",
+                    "detekt-baseline-debug.xml",
+                    "detekt-baseline-releaseUnitTest.xml",
+                    "detekt-baseline-debugUnitTest.xml",
+                    "detekt-baseline-debugAndroidTest.xml"
+                )
+            )
+        }
+        val gradleRunner = createGradleRunnerAndSetupProject(projectLayout).also {
+            it.writeProjectFile("android_lib/src/main/AndroidManifest.xml", manifestContent())
+        }
+
+        @Test
+        @DisplayName("task :android_lib:detektMain")
+        fun libDetektMain() {
+            gradleRunner.runTasksAndCheckResult(
+                "--configuration-cache",
+                ":android_lib:detektMain",
+            ) { buildResult ->
+                assertThat(buildResult.output).contains("Configuration cache")
+                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-release.xml """)
+                assertThat(buildResult.output).containsPattern("""--baseline \S*[/\\]detekt-baseline-debug.xml """)
+                assertThat(buildResult.output).contains("--report xml:")
+                assertThat(buildResult.output).contains("--report sarif:")
+                assertThat(buildResult.output).doesNotContain("--report txt:")
+                assertThat(buildResult.tasks.map { it.path }).containsAll(
+                    listOf(
+                        ":android_lib:detektMain",
+                    )
+                )
+            }
+        }
+
+        @Test
+        @DisplayName("task :android_lib:detektTest")
+        fun libDetektTest() {
+            gradleRunner.runTasksAndCheckResult(
+                "--configuration-cache",
+                ":android_lib:detektTest",
+            ) { buildResult ->
+                assertThat(buildResult.output).contains("Configuration cache")
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-debugUnitTest.xml """
+                )
+                assertThat(buildResult.output).containsPattern(
+                    """--baseline \S*[/\\]detekt-baseline-debugAndroidTest.xml """
+                )
+                assertThat(buildResult.output).contains("--report xml:")
+                assertThat(buildResult.output).contains("--report sarif:")
+                assertThat(buildResult.output).doesNotContain("--report txt:")
+                assertThat(buildResult.tasks.map { it.path }).containsAll(
+                    listOf(
+                        ":android_lib:detektTest",
+                    )
+                )
+            }
+        }
+    }
+
     @Nested
     inner class `configures android tasks for different build variants` {
 
@@ -498,15 +610,22 @@ private val LIB_PLUGIN_BLOCK = """
     }
 """.trimIndent()
 
+private val KOTLIN_ONLY_LIB_PLUGIN_BLOCK = """
+    plugins {
+        kotlin("jvm")
+        id("io.gitlab.arturbosch.detekt")
+    }
+""".trimIndent()
+
 private val ANDROID_BLOCK = """
     android {
-       compileSdkVersion(30)
+       compileSdk = 30
     }
 """.trimIndent()
 
 private val ANDROID_BLOCK_WITH_FLAVOR = """
     android {
-        compileSdkVersion(30)
+        compileSdk = 30
         flavorDimensions("age", "name")
         productFlavors {
            create("harry") {
@@ -524,10 +643,10 @@ private val ANDROID_BLOCK_WITH_FLAVOR = """
 
 private val ANDROID_BLOCK_WITH_VIEW_BINDING = """
     android {
-        compileSdkVersion(30)
+        compileSdk = 30
         defaultConfig {
             applicationId = "io.gitlab.arturbosch.detekt.app"
-            minSdkVersion(24)
+            minSdk = 24
         }
         buildFeatures {
             viewBinding = true
