@@ -76,10 +76,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |    config.setFrom(files("firstConfig.yml", "secondConfig.yml"))
-                    |}
+                |detekt {
+                |    config.setFrom(files("firstConfig.yml", "secondConfig.yml"))
+                |}
             """
 
             gradleRunner = builder.withDetektConfig(config).build()
@@ -103,10 +104,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |   baseline = file("$baselineFilename")
-                    |}
+                |detekt {
+                |   baseline = file("$baselineFilename")
+                |}
             """
 
             gradleRunner = builder
@@ -130,10 +132,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |   baseline = file("$baselineFilename")
-                    |}
+                |detekt {
+                |   baseline = file("$baselineFilename")
+                |}
             """
 
             gradleRunner = builder
@@ -156,10 +159,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |    input = files("$customSrc1", "$customSrc2", "folder_that_does_not_exist")
-                    |}
+                |detekt {
+                |    input = files("$customSrc1", "$customSrc2", "folder_that_does_not_exist")
+                |}
             """
 
             val projectLayout = ProjectLayout(1, srcDirs = listOf(customSrc1, customSrc2))
@@ -191,10 +195,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |    source = files("$customSrc1", "$customSrc2", "folder_that_does_not_exist")
-                    |}
+                |detekt {
+                |    source = files("$customSrc1", "$customSrc2", "folder_that_does_not_exist")
+                |}
             """
 
             val projectLayout = ProjectLayout(1, srcDirs = listOf(customSrc1, customSrc2))
@@ -224,10 +229,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |    reportsDir = file("build/detekt-reports")
-                    |}
+                |detekt {
+                |    reportsDir = file("build/detekt-reports")
+                |}
             """
 
             gradleRunner = builder
@@ -266,16 +272,17 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |    reportsDir = file("build/detekt-reports")
-                    |}
-                    |
-                    |tasks.detekt {
-                    |    reports {
-                    |        xml.destination = file("build/xml-reports/custom-detekt.xml")
-                    |    }
-                    |}
+                |detekt {
+                |    reportsDir = file("build/detekt-reports")
+                |}
+                |
+                |tasks.detekt {
+                |    reports {
+                |        xml.destination = file("build/xml-reports/custom-detekt.xml")
+                |    }
+                |}
             """
 
             gradleRunner = builder
@@ -308,24 +315,25 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |tasks.detekt {
-                    |    reports {
-                    |        xml.enabled = false
-                    |        html {
-                    |            enabled = false
-                    |        }
-                    |        txt {
-                    |            enabled = false
-                    |        }
-                    |        sarif {
-                    |            enabled = false
-                    |        }
-                    |        md {
-                    |            enabled = false
-                    |        }
-                    |    }
-                    |}
+                |tasks.detekt {
+                |    reports {
+                |        xml.enabled = false
+                |        html {
+                |            enabled = false
+                |        }
+                |        txt {
+                |            enabled = false
+                |        }
+                |        sarif {
+                |            enabled = false
+                |        }
+                |        md {
+                |            enabled = false
+                |        }
+                |    }
+                |}
             """
 
             gradleRunner = builder
@@ -346,19 +354,20 @@ class DetektTaskDslSpec {
         inner class `configured correctly` {
             @BeforeAll
             fun beforeGroup() {
+                @Suppress("TrimMultilineRawString")
                 val config = """
-                            |tasks.detekt {
-                            |    reports {
-                            |        custom {
-                            |           reportId = "customXml"
-                            |           destination = file("build/reports/custom.xml")
-                            |       }
-                            |        custom {
-                            |           reportId = "customJson"
-                            |           destination = file("build/reports/custom.json")
-                            |       }
-                            |    }
-                            |}
+                    |tasks.detekt {
+                    |    reports {
+                    |        custom {
+                    |           reportId = "customXml"
+                    |           destination = file("build/reports/custom.xml")
+                    |       }
+                    |        custom {
+                    |           reportId = "customJson"
+                    |           destination = file("build/reports/custom.json")
+                    |       }
+                    |    }
+                    |}
                 """
 
                 gradleRunner = builder.withDetektConfig(config).build()
@@ -382,14 +391,15 @@ class DetektTaskDslSpec {
         inner class `report id is missing` {
             @BeforeAll
             fun beforeGroup() {
+                @Suppress("TrimMultilineRawString")
                 val config = """
-                            |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
-                            |    reports {
-                            |        custom {
-                            |           destination = file("build/reports/custom.xml")
-                            |       }
-                            |    }
-                            |}
+                    |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
+                    |    reports {
+                    |        custom {
+                    |           destination = file("build/reports/custom.xml")
+                    |       }
+                    |    }
+                    |}
                 """
 
                 gradleRunner = builder.withDetektConfig(config).build()
@@ -408,14 +418,15 @@ class DetektTaskDslSpec {
         inner class `report filename is missing` {
             @BeforeAll
             fun beforeGroup() {
+                @Suppress("TrimMultilineRawString")
                 val config = """
-                            |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
-                            |    reports {
-                            |        custom {
-                            |           reportId = "customJson"
-                            |       }
-                            |    }
-                            |}
+                    |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
+                    |    reports {
+                    |        custom {
+                    |           reportId = "customJson"
+                    |       }
+                    |    }
+                    |}
                 """
 
                 gradleRunner = builder.withDetektConfig(config).build()
@@ -436,15 +447,16 @@ class DetektTaskDslSpec {
             fun beforeGroup() {
                 val aDirectory = "\${rootDir}/src"
 
+                @Suppress("TrimMultilineRawString")
                 val config = """
-                            |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
-                            |    reports {
-                            |        custom {
-                            |           reportId = "foo"
-                            |           destination = file("$aDirectory")
-                            |       }
-                            |    }
-                            |}
+                    |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
+                    |    reports {
+                    |        custom {
+                    |           reportId = "foo"
+                    |           destination = file("$aDirectory")
+                    |       }
+                    |    }
+                    |}
                 """
 
                 gradleRunner = builder.withDetektConfig(config).build()
@@ -463,15 +475,16 @@ class DetektTaskDslSpec {
             @ParameterizedTest
             @EnumSource(DetektReportType::class)
             fun `fails the build`(wellKnownType: DetektReportType) {
+                @Suppress("TrimMultilineRawString")
                 val config = """
-                                    |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
-                                    |    reports {
-                                    |        custom {
-                                    |            reportId = "${wellKnownType.reportId}"
-                                    |            destination = file("build/reports/custom.xml")
-                                    |        }
-                                    |    }
-                                    |}
+                    |tasks.withType<io.gitlab.arturbosch.detekt.Detekt>().configureEach {
+                    |    reports {
+                    |        custom {
+                    |            reportId = "${wellKnownType.reportId}"
+                    |            destination = file("build/reports/custom.xml")
+                    |        }
+                    |    }
+                    |}
                 """
 
                 gradleRunner = builder.withDetektConfig(config).build()
@@ -488,17 +501,17 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                    |detekt {
-                    |    debug = true
-                    |    parallel = true
-                    |    disableDefaultRuleSets = true
-                    |    failFast = true
-                    |    allRules = true
-                    |    autoCorrect = true
-                    |    buildUponDefaultConfig = true
-                    |    ignoreFailures = true
-                    |}
+                |detekt {
+                |    debug = true
+                |    parallel = true
+                |    disableDefaultRuleSets = true
+                |    allRules = true
+                |    autoCorrect = true
+                |    buildUponDefaultConfig = true
+                |    ignoreFailures = true
+                |}
             """
 
             gradleRunner = builder
@@ -532,11 +545,6 @@ class DetektTaskDslSpec {
             assertThat(result.output).contains("--all-rules")
         }
 
-        @Test
-        fun `enables fail fast`() {
-            assertThat(result.output).contains("--fail-fast")
-        }
-
         @Test
         fun `enables auto correcting`() {
             assertThat(result.output).contains("--auto-correct")
@@ -567,10 +575,11 @@ class DetektTaskDslSpec {
     inner class `with an additional plugin` {
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                        |dependencies {
-                        |   detektPlugins("io.gitlab.arturbosch.detekt:detekt-formatting:$defaultDetektVersion")
-                        |}
+                |dependencies {
+                |   detektPlugins("io.gitlab.arturbosch.detekt:detekt-formatting:$defaultDetektVersion")
+                |}
             """
 
             gradleRunner = builder
@@ -596,10 +605,11 @@ class DetektTaskDslSpec {
 
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
-                        |detekt {
-                        |    toolVersion = "$customVersion"
-                        |}
+                |detekt {
+                |    toolVersion = "$customVersion"
+                |}
             """
 
             gradleRunner = builder
@@ -623,6 +633,7 @@ class DetektTaskDslSpec {
     inner class `and creating a custom task` {
         @BeforeAll
         fun beforeGroup() {
+            @Suppress("TrimMultilineRawString")
             val config = """
                 |task<io.gitlab.arturbosch.detekt.Detekt>("myDetekt") {
                 |    description = "Runs a custom detekt build."
@@ -635,7 +646,6 @@ class DetektTaskDslSpec {
                 |    parallel = true
                 |    disableDefaultRuleSets = true
                 |    buildUponDefaultConfig = true
-                |    failFast = false
                 |    allRules = false
                 |    ignoreFailures = false
                 |    autoCorrect = false
