@@ -15,7 +15,9 @@ class JvmSpec {
             .buildAndFail()
 
         assertThat(result.output).contains("failed with 2 weighted issues.")
-        assertThat(result.output).contains("Do not directly exit the process outside the `main` function. Throw an exception(...)")
+        assertThat(result.output).contains(
+            "Do not directly exit the process outside the `main` function. Throw an exception(...)"
+        )
         assertThat(result.output).contains("Errors.kt:7:9")
         assertThat(result.output).contains("Errors.kt:12:16")
     }
