@@ -17,8 +17,8 @@ import io.gitlab.arturbosch.detekt.invoke.DebugArgument
 import io.gitlab.arturbosch.detekt.invoke.DefaultReportArgument
 import io.gitlab.arturbosch.detekt.invoke.DetektInvoker
 import io.gitlab.arturbosch.detekt.invoke.DisableDefaultRuleSetArgument
-import io.gitlab.arturbosch.detekt.invoke.FailFastArgument
 import io.gitlab.arturbosch.detekt.invoke.InputArgument
+import io.gitlab.arturbosch.detekt.invoke.JdkHomeArgument
 import io.gitlab.arturbosch.detekt.invoke.JvmTargetArgument
 import io.gitlab.arturbosch.detekt.invoke.LanguageVersionArgument
 import io.gitlab.arturbosch.detekt.invoke.ParallelArgument
@@ -26,6 +26,7 @@ import io.gitlab.arturbosch.detekt.invoke.isDryRunEnabled
 import org.gradle.api.Action
 import org.gradle.api.file.ConfigurableFileCollection
 import org.gradle.api.file.Directory
+import org.gradle.api.file.DirectoryProperty
 import org.gradle.api.file.FileTree
 import org.gradle.api.file.RegularFile
 import org.gradle.api.file.RegularFileProperty
@@ -38,6 +39,7 @@ import org.gradle.api.tasks.Classpath
 import org.gradle.api.tasks.Console
 import org.gradle.api.tasks.IgnoreEmptyDirectories
 import org.gradle.api.tasks.Input
+import org.gradle.api.tasks.InputDirectory
 import org.gradle.api.tasks.InputFile
 import org.gradle.api.tasks.InputFiles
 import org.gradle.api.tasks.Internal
@@ -56,33 +58,33 @@ import java.io.File
 import javax.inject.Inject
 
 @CacheableTask
-open class Detekt @Inject constructor(
+abstract class Detekt @Inject constructor(
     private val objects: ObjectFactory
 ) : SourceTask(), VerificationTask {
 
     @get:Classpath
-    val detektClasspath: ConfigurableFileCollection = objects.fileCollection()
+    abstract val detektClasspath: ConfigurableFileCollection
 
     @get:Classpath
-    val pluginClasspath: ConfigurableFileCollection = objects.fileCollection()
+    abstract val pluginClasspath: ConfigurableFileCollection
 
     @get:InputFile
     @get:Optional
     @get:PathSensitive(PathSensitivity.RELATIVE)
-    val baseline: RegularFileProperty = project.objects.fileProperty()
+    abstract val baseline: RegularFileProperty
 
     @get:InputFiles
     @get:Optional
     @get:PathSensitive(PathSensitivity.RELATIVE)
-    val config: ConfigurableFileCollection = objects.fileCollection()
+    abstract val config: ConfigurableFileCollection
 
     @get:Classpath
     @get:Optional
-    val classpath: ConfigurableFileCollection = objects.fileCollection()
+    abstract val classpath: ConfigurableFileCollection
 
     @get:Input
     @get:Optional
-    internal val languageVersionProp: Property<String> = project.objects.property(String::class.javaObjectType)
+    internal abstract val languageVersionProp: Property<String>
     var languageVersion: String
         @Internal
         get() = languageVersionProp.get()
@@ -90,61 +92,57 @@ open class Detekt @Inject constructor(
 
     @get:Input
     @get:Optional
-    internal val jvmTargetProp: Property<String> = project.objects.property(String::class.javaObjectType)
+    internal abstract val jvmTargetProp: Property<String>
     var jvmTarget: String
         @Internal
         get() = jvmTargetProp.get()
         set(value) = jvmTargetProp.set(value)
 
+    @get:InputDirectory
+    @get:PathSensitive(PathSensitivity.ABSOLUTE)
+    @get:Optional
+    abstract val jdkHome: DirectoryProperty
+
     @get:Internal
-    internal val debugProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val debugProp: Property<Boolean>
     var debug: Boolean
         @Console
         get() = debugProp.getOrElse(false)
         set(value) = debugProp.set(value)
 
     @get:Internal
-    internal val parallelProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val parallelProp: Property<Boolean>
     var parallel: Boolean
         @Internal
         get() = parallelProp.getOrElse(false)
         set(value) = parallelProp.set(value)
 
     @get:Internal
-    internal val disableDefaultRuleSetsProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val disableDefaultRuleSetsProp: Property<Boolean>
     var disableDefaultRuleSets: Boolean
         @Input
         get() = disableDefaultRuleSetsProp.getOrElse(false)
         set(value) = disableDefaultRuleSetsProp.set(value)
 
     @get:Internal
-    internal val buildUponDefaultConfigProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val buildUponDefaultConfigProp: Property<Boolean>
     var buildUponDefaultConfig: Boolean
         @Input
         get() = buildUponDefaultConfigProp.getOrElse(false)
         set(value) = buildUponDefaultConfigProp.set(value)
 
     @get:Internal
-    internal val failFastProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
-
-    @Deprecated("Please use the buildUponDefaultConfig and allRules flags instead.", ReplaceWith("allRules"))
-    var failFast: Boolean
-        @Input
-        get() = failFastProp.getOrElse(false)
-        set(value) = failFastProp.set(value)
-
-    @get:Internal
-    internal val allRulesProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val allRulesProp: Property<Boolean>
     var allRules: Boolean
         @Input
         get() = allRulesProp.getOrElse(false)
         set(value) = allRulesProp.set(value)
 
     @get:Internal
-    internal val ignoreFailuresProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val ignoreFailuresProp: Property<Boolean>
 
     @get:Internal
-    internal val autoCorrectProp: Property<Boolean> = project.objects.property(Boolean::class.javaObjectType)
+    internal abstract val autoCorrectProp: Property<Boolean>
 
     @set:Option(option = "auto-correct", description = "Allow rules to auto correct code if they support it")
     var autoCorrect: Boolean
@@ -157,7 +155,7 @@ open class Detekt @Inject constructor(
      */
     @get:Input
     @get:Optional
-    internal val basePathProp: Property<String> = project.objects.property(String::class.java)
+    internal abstract val basePathProp: Property<String>
     var basePath: String
         @Internal
         get() = basePathProp.getOrElse("")
@@ -167,7 +165,7 @@ open class Detekt @Inject constructor(
     var reports: DetektReports = objects.newInstance(DetektReports::class.java)
 
     @get:Internal
-    val reportsDir: Property<File> = project.objects.property(File::class.java)
+    abstract val reportsDir: Property<File>
 
     val xmlReportFile: Provider<RegularFile>
         @OutputFile
@@ -210,12 +208,13 @@ open class Detekt @Inject constructor(
     }
 
     @get:Internal
-    internal val arguments: Provider<List<String>> = project.provider {
-        listOf(
+    internal val arguments
+        get() = listOf(
             InputArgument(source),
             ClasspathArgument(classpath),
             LanguageVersionArgument(languageVersionProp.orNull),
             JvmTargetArgument(jvmTargetProp.orNull),
+            JdkHomeArgument(jdkHome),
             ConfigArgument(config),
             BaselineArgument(baseline.orNull),
             DefaultReportArgument(DetektReportType.XML, xmlReportFile.orNull),
@@ -226,13 +225,11 @@ open class Detekt @Inject constructor(
             DebugArgument(debugProp.getOrElse(false)),
             ParallelArgument(parallelProp.getOrElse(false)),
             BuildUponDefaultConfigArgument(buildUponDefaultConfigProp.getOrElse(false)),
-            FailFastArgument(failFastProp.getOrElse(false)),
             AllRulesArgument(allRulesProp.getOrElse(false)),
             AutoCorrectArgument(autoCorrectProp.getOrElse(false)),
             BasePathArgument(basePathProp.orNull),
             DisableDefaultRuleSetArgument(disableDefaultRuleSetsProp.getOrElse(false))
         ).plus(convertCustomReportsToArguments()).flatMap(CliArgument::toArgument)
-    }
 
     @InputFiles
     @SkipWhenEmpty
@@ -253,12 +250,8 @@ open class Detekt @Inject constructor(
 
     @TaskAction
     fun check() {
-        if (failFastProp.getOrElse(false)) {
-            logger.warn("'failFast' is deprecated. Please use 'buildUponDefaultConfig' together with 'allRules'.")
-        }
-
         DetektInvoker.create(task = this, isDryRun = isDryRun).invokeCli(
-            arguments = arguments.get(),
+            arguments = arguments,
             ignoreFailures = ignoreFailures,
             classpath = detektClasspath.plus(pluginClasspath),
             taskName = name
