@@ -1,16 +1,14 @@
 package io.gitlab.arturbosch.detekt.extensions
 
 import org.gradle.api.file.RegularFileProperty
-import org.gradle.api.model.ObjectFactory
 import org.gradle.api.tasks.Internal
 import org.gradle.api.tasks.OutputFile
 import java.io.File
-import javax.inject.Inject
 
-open class CustomDetektReport @Inject constructor(objects: ObjectFactory) {
+abstract class CustomDetektReport {
 
-    @Internal
-    var reportId: String? = null
+    @get:Internal
+    abstract var reportId: String?
 
     @Deprecated("Use outputLocation.set(value)")
     @get:Internal
@@ -20,8 +18,8 @@ open class CustomDetektReport @Inject constructor(objects: ObjectFactory) {
             outputLocation.set(value)
         }
 
-    @OutputFile
-    val outputLocation: RegularFileProperty = objects.fileProperty()
+    @get:OutputFile
+    abstract val outputLocation: RegularFileProperty
 
     override fun toString(): String {
         return "CustomDetektReport(reportId=$reportId, outputLocation=$outputLocation)"
