@@ -1,6 +1,9 @@
 package io.github.detekt.psi
 
+import org.jetbrains.kotlin.com.intellij.openapi.util.TextRange
 import org.jetbrains.kotlin.com.intellij.psi.PsiFile
+import org.jetbrains.kotlin.diagnostics.DiagnosticUtils
+import org.jetbrains.kotlin.diagnostics.PsiDiagnosticUtils
 import java.io.File
 import java.nio.file.Path
 import java.nio.file.Paths
@@ -68,6 +71,14 @@ fun PsiFile.toFilePath(): FilePath {
     }
 }
 
+// #3317 If any rule mutates the PsiElement, searching the original PsiElement may throw an exception.
+fun getLineAndColumnInPsiFile(file: PsiFile, range: TextRange): PsiDiagnosticUtils.LineAndColumn? {
+    return runCatching {
+        @Suppress("ForbiddenMethodCall")
+        DiagnosticUtils.getLineAndColumnInPsiFile(file, range)
+    }.getOrNull()
+}
+
 /**
  * Returns a system-independent string with UNIX system file separator.
  */
