@@ -5,6 +5,7 @@ import org.jetbrains.kotlin.psi.KtBinaryExpression
 import org.jetbrains.kotlin.psi.KtExpression
 import org.jetbrains.kotlin.psi.KtIfExpression
 import org.jetbrains.kotlin.psi.KtNamedFunction
+import org.jetbrains.kotlin.psi.psiUtil.anyDescendantOfType
 import org.jetbrains.kotlin.psi.psiUtil.findDescendantOfType
 import org.jetbrains.kotlin.psi.psiUtil.lastBlockStatementOrThis
 
@@ -23,7 +24,7 @@ inline fun <reified T : KtExpression> KtNamedFunction.yieldStatementsSkippingGua
 
 inline fun <reified T : KtExpression> KtExpression.isGuardClause(): Boolean {
     val descendantExpr = this.findDescendantOfType<T>() ?: return false
-    return this.isIfConditionGuardClause(descendantExpr) || this.isElvisOperatorGuardClause()
+    return this.isIfConditionGuardClause(descendantExpr) || this.isElvisOperatorGuardClause(descendantExpr)
 }
 
 fun <T : KtExpression> KtExpression.isIfConditionGuardClause(descendantExpr: T): Boolean {
@@ -32,7 +33,5 @@ fun <T : KtExpression> KtExpression.isIfConditionGuardClause(descendantExpr: T):
         descendantExpr === ifExpr.then?.lastBlockStatementOrThis()
 }
 
-fun KtExpression.isElvisOperatorGuardClause(): Boolean {
-    val elvisExpr = this.findDescendantOfType<KtBinaryExpression>() ?: return false
-    return elvisExpr.operationToken == KtTokens.ELVIS
-}
+fun <T : KtExpression> KtExpression.isElvisOperatorGuardClause(descendantExpr: T): Boolean =
+    this.anyDescendantOfType<KtBinaryExpression> { it.operationToken == KtTokens.ELVIS && it.right == descendantExpr }
