@@ -1,8 +1,8 @@
 package io.gitlab.arturbosch.detekt.rules.complexity
 
 import io.gitlab.arturbosch.detekt.test.TestConfig
+import io.gitlab.arturbosch.detekt.test.assertThat
 import io.gitlab.arturbosch.detekt.test.compileAndLint
-import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.Test
 
 class LabeledExpressionSpec {
@@ -20,7 +20,7 @@ class LabeledExpressionSpec {
                     }
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(3)
     }
 
@@ -33,8 +33,12 @@ class LabeledExpressionSpec {
                     println(it)
                 }
             }
-        """
-        assertThat(subject.compileAndLint(code)).hasSize(1)
+        """.trimIndent()
+
+        val findings = subject.compileAndLint(code)
+
+        assertThat(findings).hasSize(1)
+        assertThat(findings).hasStartSourceLocation(3, 28)
     }
 
     @Test
@@ -46,7 +50,7 @@ class LabeledExpressionSpec {
                     println(it)
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(2)
     }
 
@@ -65,7 +69,7 @@ class LabeledExpressionSpec {
                     }
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(3)
     }
 
@@ -79,7 +83,7 @@ class LabeledExpressionSpec {
                 }
             }
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -94,7 +98,7 @@ class LabeledExpressionSpec {
                 }
             }
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -108,7 +112,7 @@ class LabeledExpressionSpec {
                 }
             }
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -129,7 +133,7 @@ class LabeledExpressionSpec {
                 }
             }
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -139,7 +143,7 @@ class LabeledExpressionSpec {
             fun f() {
                 loop@ for (i in 1..5) {}
             }
-        """
+        """.trimIndent()
         val config = TestConfig(mapOf("ignoredLabels" to listOf("loop")))
         val findings = LabeledExpression(config).compileAndLint(code)
         assertThat(findings).isEmpty()
@@ -151,7 +155,7 @@ class LabeledExpressionSpec {
             fun f() {
                 loop@ for (i in 1..5) {}
             }
-        """
+        """.trimIndent()
         val config = TestConfig(mapOf("ignoredLabels" to "loop"))
         val findings = LabeledExpression(config).compileAndLint(code)
         assertThat(findings).isEmpty()
@@ -163,7 +167,7 @@ class LabeledExpressionSpec {
             fun f() {
                 loop@ for (i in 1..5) {}
             }
-        """
+        """.trimIndent()
         val config = TestConfig(mapOf("ignoredLabels" to "*loop*,other"))
         val findings = LabeledExpression(config).compileAndLint(code)
         assertThat(findings).isEmpty()
