@@ -5,7 +5,6 @@ plugins {
 dependencies {
     compileOnly(projects.detektApi)
     testImplementation(projects.detektTest)
-    testImplementation(libs.bundles.testImplementation)
-    testRuntimeOnly(libs.spek.runner)
+    testImplementation(libs.assertj)
     testRuntimeOnly(libs.kotlinx.coroutines)
 }
