@@ -29,7 +29,7 @@ class InjectDispatcherSpec(val env: KotlinCoreEnvironment) {
                         launch(Dispatchers.IO) { }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
         }
 
@@ -46,7 +46,7 @@ class InjectDispatcherSpec(val env: KotlinCoreEnvironment) {
                         launch(dispatcher) { }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
 
@@ -57,7 +57,20 @@ class InjectDispatcherSpec(val env: KotlinCoreEnvironment) {
                 import kotlinx.coroutines.Dispatchers
 
                 class MyRepository(dispatcher: CoroutineDispatcher = Dispatchers.IO)
-            """
+            """.trimIndent()
+            assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
+        }
+
+        @Test
+        fun `does not report when dispatcher is used as a secondary constructor parameter`() {
+            val code = """
+                import kotlinx.coroutines.CoroutineDispatcher
+                import kotlinx.coroutines.Dispatchers
+
+                class MyRepository(dispatcher: CoroutineDispatcher) {
+                    constructor() : this(Dispatchers.IO)
+                }
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
 
@@ -68,7 +81,7 @@ class InjectDispatcherSpec(val env: KotlinCoreEnvironment) {
                 import kotlinx.coroutines.Dispatchers
 
                 class MyRepository(private val dispatcher: CoroutineDispatcher = Dispatchers.IO)
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
 
@@ -84,7 +97,7 @@ class InjectDispatcherSpec(val env: KotlinCoreEnvironment) {
                         launch(Dispatchers.Main) { }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
     }
@@ -106,7 +119,7 @@ class InjectDispatcherSpec(val env: KotlinCoreEnvironment) {
                         launch(Dispatchers.Main) { }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
         }
     }
