@@ -1,10 +1,12 @@
 package io.gitlab.arturbosch.detekt.rules.documentation
 
+import io.gitlab.arturbosch.detekt.test.assertThat
 import io.gitlab.arturbosch.detekt.test.compileAndLint
-import org.assertj.core.api.Assertions.assertThat
+import org.junit.jupiter.api.Nested
 import org.junit.jupiter.api.Test
 
 class EndOfSentenceFormatSpec {
+
     val subject = EndOfSentenceFormat()
 
     @Test
@@ -13,7 +15,7 @@ class EndOfSentenceFormatSpec {
         /** Some doc */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -23,7 +25,7 @@ class EndOfSentenceFormatSpec {
             /** Some doc */
             fun f(x: Int, y: Int, z: Int) = 
                 if (x == 0) y + z else x + y
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -34,7 +36,7 @@ class EndOfSentenceFormatSpec {
             /** Some doc */
             val test = 3
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -43,7 +45,7 @@ class EndOfSentenceFormatSpec {
         val code = """
         /** Some doc */
         fun test() = 3
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -54,7 +56,7 @@ class EndOfSentenceFormatSpec {
             /** Some doc */
             fun test() = 3
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -65,7 +67,7 @@ class EndOfSentenceFormatSpec {
             /** Some doc-- */
             fun test() = 3
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -77,7 +79,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -91,7 +93,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -102,7 +104,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -116,7 +118,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -136,10 +138,25 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
+    @Test
+    fun `reports invalid KDoc even when it looks like it contains html tags`() {
+        val code = """
+        /**
+         * < is the less-than sign --
+         * ```
+         * <code>this contains HTML, but doesn't start with a tag</code>
+         * ```
+         */
+        class Test {
+        }
+        """.trimIndent()
+        assertThat(subject.compileAndLint(code)).hasSize(1)
+    }
+
     @Test
     fun `does not report KDoc ending with periods`() {
         val code = """
@@ -148,7 +165,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -160,7 +177,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -172,7 +189,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -184,7 +201,7 @@ class EndOfSentenceFormatSpec {
          */
         class Test {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -199,7 +216,54 @@ class EndOfSentenceFormatSpec {
         http://google.com */
         class Test2 {
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
+
+    @Nested
+    inner class `highlights only the relevant part of the comment - #5310` {
+
+        @Test
+        fun function() {
+            val code = """
+                /**
+                 * This sentence is correct invalid
+                 *
+                 * This sentence counts too, because it doesn't know where the other ends */
+                fun test() = 3
+            """.trimIndent()
+            assertThat(subject.compileAndLint(code)).hasSize(1)
+                .hasStartSourceLocation(2, 2)
+                .hasEndSourceLocation(4, 75)
+        }
+
+        @Test
+        fun property() {
+            val code = """
+                class Test {
+                    /** This sentence is correct invalid
+                        This sentence counts too, because it doesn't know where the other ends */
+                    val test = 3
+                }
+            """.trimIndent()
+            assertThat(subject.compileAndLint(code)).hasSize(1)
+                .hasStartSourceLocation(2, 8)
+                .hasEndSourceLocation(3, 80)
+        }
+
+        @Test
+        fun `class`() {
+            val code = """
+                /**
+                 * This sentence is correct invalid
+                 *
+                 * This sentence counts too, because it doesn't know where the other ends
+                 */
+                class Test
+            """.trimIndent()
+            assertThat(subject.compileAndLint(code)).hasSize(1)
+                .hasStartSourceLocation(2, 2)
+                .hasEndSourceLocation(4, 74)
+        }
+    }
 }
