@@ -1,10 +1,13 @@
 package io.gitlab.arturbosch.detekt.rules.documentation
 
+import io.gitlab.arturbosch.detekt.test.TestConfig
 import io.gitlab.arturbosch.detekt.test.compileAndLint
 import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.Nested
 import org.junit.jupiter.api.Test
 
+private const val SEARCH_PROTECTED_FUN = "searchProtectedFunction"
+
 class UndocumentedPublicFunctionSpec {
     val subject = UndocumentedPublicFunction()
 
@@ -12,7 +15,7 @@ class UndocumentedPublicFunctionSpec {
     fun `reports undocumented public functions`() {
         val code = """
             fun noComment1() {}
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -22,7 +25,7 @@ class UndocumentedPublicFunctionSpec {
             object Test {
                 fun noComment1() {}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -34,7 +37,7 @@ class UndocumentedPublicFunctionSpec {
                     fun noComment1() {}
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -47,7 +50,7 @@ class UndocumentedPublicFunctionSpec {
                     public fun noComment2() {}
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(2)
     }
 
@@ -57,7 +60,7 @@ class UndocumentedPublicFunctionSpec {
             interface Test {
                 fun noComment1()
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).hasSize(1)
     }
 
@@ -68,7 +71,7 @@ class UndocumentedPublicFunctionSpec {
              * Comment
              */
             fun commented1() {}
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -81,7 +84,7 @@ class UndocumentedPublicFunctionSpec {
             */
             fun commented() {}
         }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -92,7 +95,7 @@ class UndocumentedPublicFunctionSpec {
                 internal fun no1(){}
                 private fun no2(){}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -105,7 +108,7 @@ class UndocumentedPublicFunctionSpec {
             fun commented() {
                 fun iDontNeedDoc() {}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -116,7 +119,7 @@ class UndocumentedPublicFunctionSpec {
                 fun nope1() {}
                 public fun nope2() {}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -127,7 +130,7 @@ class UndocumentedPublicFunctionSpec {
                 fun nope1() {}
                 public fun nope2() {}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -137,10 +140,31 @@ class UndocumentedPublicFunctionSpec {
             private object Test {
                 fun noComment1() {}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
+    @Test
+    fun `does not report protected functions by default`() {
+        val code = """
+            open class Test {
+                protected fun noComment1() {}
+            }
+        """.trimIndent()
+        assertThat(subject.compileAndLint(code)).isEmpty()
+    }
+
+    @Test
+    fun `reports protected functions if configured`() {
+        val code = """
+            open class Test {
+                protected fun noComment1() {}
+            }
+        """.trimIndent()
+        val subject = UndocumentedPublicFunction(TestConfig(mapOf(SEARCH_PROTECTED_FUN to "true")))
+        assertThat(subject.compileAndLint(code)).hasSize(1)
+    }
+
     @Nested
     inner class `nested class` {
         @Test
@@ -152,7 +176,7 @@ class UndocumentedPublicFunctionSpec {
                         }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLint(code)).isEmpty()
         }
 
@@ -167,7 +191,7 @@ class UndocumentedPublicFunctionSpec {
                         }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLint(code)).isEmpty()
         }
 
@@ -180,7 +204,7 @@ class UndocumentedPublicFunctionSpec {
                         }
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLint(code)).isEmpty()
         }
     }
