@@ -8,6 +8,7 @@ import io.gitlab.arturbosch.detekt.api.Issue
 import io.gitlab.arturbosch.detekt.api.Rule
 import io.gitlab.arturbosch.detekt.api.Severity
 import io.gitlab.arturbosch.detekt.api.internal.RequiresTypeResolution
+import io.gitlab.arturbosch.detekt.rules.getDataFlowAwareTypes
 import io.gitlab.arturbosch.detekt.rules.safeAs
 import org.jetbrains.kotlin.com.intellij.psi.PsiElement
 import org.jetbrains.kotlin.descriptors.CallableDescriptor
@@ -20,7 +21,6 @@ import org.jetbrains.kotlin.psi.KtSafeQualifiedExpression
 import org.jetbrains.kotlin.psi.KtSimpleNameExpression
 import org.jetbrains.kotlin.psi.KtStringTemplateEntry
 import org.jetbrains.kotlin.psi.psiUtil.getStrictParentOfType
-import org.jetbrains.kotlin.resolve.BindingContext
 import org.jetbrains.kotlin.resolve.calls.util.getResolvedCall
 import org.jetbrains.kotlin.resolve.descriptorUtil.fqNameOrNull
 import org.jetbrains.kotlin.types.isFlexible
@@ -61,7 +61,6 @@ class NullableToStringCall(config: Config = Config.empty) : Rule(config) {
 
     override fun visitSimpleNameExpression(expression: KtSimpleNameExpression) {
         super.visitSimpleNameExpression(expression)
-        if (bindingContext == BindingContext.EMPTY) return
 
         val simpleOrCallExpression = expression.parent.safeAs<KtCallExpression>() ?: expression
         val targetExpression = simpleOrCallExpression.targetExpression() ?: return
@@ -87,21 +86,21 @@ class NullableToStringCall(config: Config = Config.empty) : Rule(config) {
     }
 
     private fun KtExpression.isNullable(): Boolean {
+        val compilerResources = compilerResources ?: return false
+
         val safeAccessOperation = safeAs<KtSafeQualifiedExpression>()?.operationTokenNode?.safeAs<PsiElement>()
         if (safeAccessOperation != null) {
             return bindingContext.diagnostics.forElement(safeAccessOperation).none {
                 it.factory == Errors.UNNECESSARY_SAFE_CALL
             }
         }
-        val compilerResources = compilerResources ?: return false
-        val descriptor = descriptor() ?: return false
-        val originalType = descriptor.returnType ?.takeIf { it.isNullable() && !it.isFlexible() } ?: return false
-        val dataFlowInfo =
-            bindingContext[BindingContext.EXPRESSION_TYPE_INFO, this]?.dataFlowInfo ?: return false
-        val dataFlowValue =
-            compilerResources.dataFlowValueFactory.createDataFlowValue(this, originalType, bindingContext, descriptor)
-        val dataFlowTypes =
-            dataFlowInfo.getStableTypes(dataFlowValue, compilerResources.languageVersionSettings)
+        val originalType = descriptor()?.returnType?.takeIf { it.isNullable() && !it.isFlexible() } ?: return false
+        val dataFlowTypes = getDataFlowAwareTypes(
+            bindingContext,
+            compilerResources.languageVersionSettings,
+            compilerResources.dataFlowValueFactory,
+            originalType
+        )
         return dataFlowTypes.all { it.isNullable() }
     }
 
