@@ -20,7 +20,8 @@ class PotentialBugProvider : DefaultRuleSetProvider {
             Deprecation(config),
             DontDowncastCollectionTypes(config),
             DoubleMutabilityForCollection(config),
-            DuplicateCaseInWhenExpression(config),
+            @Suppress("DEPRECATION") DuplicateCaseInWhenExpression(config),
+            ElseCaseInsteadOfExhaustiveWhen(config),
             EqualsAlwaysReturnsTrueOrFalse(config),
             EqualsWithHashCodeExist(config),
             ExitOutsideMain(config),
@@ -33,10 +34,12 @@ class PotentialBugProvider : DefaultRuleSetProvider {
             LateinitUsage(config),
             MapGetWithNotNullAssertionOperator(config),
             MissingPackageDeclaration(config),
-            MissingWhenCase(config),
-            RedundantElseInWhen(config),
+            @Suppress("DEPRECATION") MissingWhenCase(config),
+            NullCheckOnMutableProperty(config),
+            @Suppress("DEPRECATION") RedundantElseInWhen(config),
             UnconditionalJumpStatementInLoop(config),
             UnnecessaryNotNullOperator(config),
+            UnnecessaryNotNullCheck(config),
             UnnecessarySafeCall(config),
             UnreachableCode(config),
             UnsafeCallOnNullableType(config),
