@@ -13,10 +13,10 @@ class CastToNullableTypeSpec {
             fun foo(a: Any?) {
                 val x: String? = a as String?
             } 
-        """
+        """.trimIndent()
         val findings = subject.compileAndLint(code)
         assertThat(findings).hasSize(1)
-        assertThat(findings).hasSourceLocation(2, 22)
+        assertThat(findings).hasStartSourceLocation(2, 24)
         assertThat(findings[0]).hasMessage("Use the safe cast ('as? String') instead of 'as String?'.")
     }
 
@@ -26,7 +26,7 @@ class CastToNullableTypeSpec {
             fun foo(a: Any?) {
                 val x: String? = a as? String
             } 
-        """
+        """.trimIndent()
         val findings = subject.compileAndLint(code)
         assertThat(findings).isEmpty()
     }
@@ -37,7 +37,7 @@ class CastToNullableTypeSpec {
             fun foo(a: Any?) {
                 val x = a is String?
             } 
-        """
+        """.trimIndent()
         val findings = subject.compileAndLint(code)
         assertThat(findings).isEmpty()
     }
@@ -48,7 +48,7 @@ class CastToNullableTypeSpec {
             fun foo(a: Any?) {
                 val x = null as String?
             }
-        """
+        """.trimIndent()
         val findings = subject.compileAndLint(code)
         assertThat(findings).isEmpty()
     }
