@@ -27,10 +27,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myList = mutableListOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -39,10 +39,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var mySet = mutableSetOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -51,10 +51,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myMap = mutableMapOf("answer" to 42)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -63,10 +63,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myArrayList = ArrayList<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -75,10 +75,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myLinkedHashSet = LinkedHashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -87,10 +87,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myHashSet = HashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -99,10 +99,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myLinkedHashMap = LinkedHashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -111,10 +111,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myHashMap = HashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -132,10 +132,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myState = MutableState("foo")
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(3, 5)
+                assertThat(result).hasStartSourceLocation(3, 5)
             }
 
             @Test
@@ -154,10 +154,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myState = mutableStateOf("foo")
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(4, 5)
+                assertThat(result).hasStartSourceLocation(4, 5)
             }
 
             @Test
@@ -177,10 +177,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myState = remember { mutableStateOf("foo") }
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(5, 5)
+                assertThat(result).hasStartSourceLocation(5, 5)
             }
         }
 
@@ -193,7 +193,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myList = mutableListOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -204,7 +204,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val mySet = mutableSetOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -215,7 +215,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myMap = mutableMapOf("answer" to 42)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -226,7 +226,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myArrayList = ArrayList<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -237,7 +237,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myLinkedHashSet = LinkedHashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -248,7 +248,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myHashSet = HashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -259,7 +259,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myLinkedHashMap = LinkedHashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -270,7 +270,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myHashMap = HashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -285,7 +285,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myList = listOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -296,7 +296,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val mySet = setOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -307,7 +307,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     val myMap = mapOf("answer" to 42)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -337,7 +337,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun main() {
                     var myState by remember { mutableStateOf("foo") }
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -354,80 +354,80 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `detects var declaration with mutable list`() {
                 val code = """
                 var myList = mutableListOf(1,2,3)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with mutable set`() {
                 val code = """
                 var mySet = mutableSetOf(1,2,3)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with mutable map`() {
                 val code = """
                 var myMap = mutableMapOf("answer" to 42)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with ArrayList`() {
                 val code = """
                 var myArrayList = ArrayList<Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with LinkedHashSet`() {
                 val code = """
                 var myLinkedHashSet = LinkedHashSet<Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with HashSet`() {
                 val code = """
                 var myHashSet = HashSet<Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with LinkedHashMap`() {
                 val code = """
                 var myLinkedHashMap = LinkedHashMap<String, Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
             fun `detects var declaration with HashMap`() {
                 val code = """
                 var myHashMap = HashMap<String, Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(1, 1)
+                assertThat(result).hasStartSourceLocation(1, 1)
             }
 
             @Test
@@ -443,10 +443,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 val code = """
                 data class MutableState<T>(var state: T)
                 var myState = MutableState("foo")
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 1)
+                assertThat(result).hasStartSourceLocation(2, 1)
             }
 
             @Test
@@ -463,10 +463,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 data class MutableState<T>(var state: T)
                 fun <T> mutableStateOf(value: T): MutableState<T> = MutableState(value)
                 var myState = mutableStateOf("foo")
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(3, 1)
+                assertThat(result).hasStartSourceLocation(3, 1)
             }
 
             @Test
@@ -484,10 +484,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 fun <T> mutableStateOf(value: T): MutableState<T> = MutableState(value)
                 fun <T> remember(calculation: () -> T): T = calculation()
                 var myState = remember { mutableStateOf("foo") }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(4, 1)
+                assertThat(result).hasStartSourceLocation(4, 1)
             }
         }
 
@@ -498,7 +498,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with mutable list`() {
                 val code = """
                 val myList = mutableListOf(1,2,3)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -507,7 +507,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with mutable set`() {
                 val code = """
                 val mySet = mutableSetOf(1,2,3)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -516,7 +516,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with mutable map`() {
                 val code = """
                 val myMap = mutableMapOf("answer" to 42)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -525,7 +525,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with ArrayList`() {
                 val code = """
                 val myArrayList = ArrayList<Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -534,7 +534,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with LinkedHashSet`() {
                 val code = """
                 val myLinkedHashSet = LinkedHashSet<Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -543,7 +543,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with HashSet`() {
                 val code = """
                 val myHashSet = HashSet<Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -552,7 +552,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with LinkedHashMap`() {
                 val code = """
                 val myLinkedHashMap = LinkedHashMap<String, Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -561,7 +561,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect val declaration with HashMap`() {
                 val code = """
                 val myHashMap = HashMap<String, Int>()
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -574,7 +574,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect var declaration with immutable list`() {
                 val code = """
                 val myList = listOf(1,2,3)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -583,7 +583,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect var declaration with immutable set`() {
                 val code = """
                 val mySet = setOf(1,2,3)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -592,7 +592,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
             fun `does not detect var declaration with immutable map`() {
                 val code = """
                 val myMap = mapOf("answer" to 42)
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -620,7 +620,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                     this.state = value
                 }
                 var myState by remember { mutableStateOf("foo") }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -639,10 +639,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myOtherList = mutableListOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -651,10 +651,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var mySet = mutableSetOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -663,10 +663,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myMap = mutableMapOf("answer" to 42)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -675,10 +675,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myArrayList = ArrayList<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -687,10 +687,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myLinkedHashSet = LinkedHashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -699,10 +699,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myHashSet = HashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -711,10 +711,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myLinkedHashMap = LinkedHashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -723,10 +723,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myHashMap = HashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(2, 5)
+                assertThat(result).hasStartSourceLocation(2, 5)
             }
 
             @Test
@@ -744,10 +744,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myState = MutableState("foo")
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(3, 5)
+                assertThat(result).hasStartSourceLocation(3, 5)
             }
 
             @Test
@@ -766,10 +766,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myState = mutableStateOf("foo")
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(4, 5)
+                assertThat(result).hasStartSourceLocation(4, 5)
             }
 
             @Test
@@ -789,10 +789,10 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myState = remember { mutableStateOf("foo") }
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).hasSize(1)
-                assertThat(result).hasSourceLocation(5, 5)
+                assertThat(result).hasStartSourceLocation(5, 5)
             }
         }
 
@@ -805,7 +805,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myList = mutableListOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -816,7 +816,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val mySet = mutableSetOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -827,7 +827,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myMap = mutableMapOf("answer" to 42)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -838,7 +838,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myArrayList = ArrayList<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -849,7 +849,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myLinkedHashSet = LinkedHashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -860,7 +860,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myHashSet = HashSet<Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -871,7 +871,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myLinkedHashMap = LinkedHashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -882,7 +882,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myHashMap = HashMap<String, Int>()
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -897,7 +897,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myList = listOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -908,7 +908,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val mySet = setOf(1,2,3)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -919,7 +919,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     val myMap = mapOf("answer" to 42)
                 }
-                """
+                """.trimIndent()
                 val result = subject.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
@@ -949,7 +949,7 @@ class DoubleMutabilityForCollectionSpec(private val env: KotlinCoreEnvironment)
                 class MyClass {
                     var myState by remember { mutableStateOf("foo") }
                 }
-                """
+                """.trimIndent()
                 val result = rule.compileAndLintWithContext(env, code)
                 assertThat(result).isEmpty()
             }
