@@ -30,7 +30,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     else -> {}
                 }
             }
-            """
+            """.trimIndent()
             val actual = subject.compileAndLintWithContext(env, code)
             assertThat(actual).hasSize(1)
         }
@@ -51,7 +51,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     else -> 100
                 }
             }
-            """
+            """.trimIndent()
             val actual = subject.compileAndLintWithContext(env, code)
             assertThat(actual).hasSize(1)
         }
@@ -85,8 +85,8 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     Color.GREEN -> {}
                 }
             }
-            """
-            assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
+            """.trimIndent()
+            assertThat(subject.lintWithContext(env, code)).isEmpty()
         }
     }
 
@@ -108,7 +108,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                         else -> {}
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
         }
 
@@ -128,7 +128,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                         else -> "other"
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
         }
 
@@ -147,8 +147,8 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                         is Variant.VariantB -> {}
                     }
                 }
-            """
-            assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
+            """.trimIndent()
+            assertThat(subject.lintWithContext(env, code)).isEmpty()
         }
     }
 
@@ -170,7 +170,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                         else -> {}
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.lintWithContext(env, code)).isEmpty()
         }
 
@@ -190,7 +190,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                         else -> "other"
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.lintWithContext(env, code)).isEmpty()
         }
     }
@@ -206,7 +206,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     else -> {}
                 }
             }
-            """
+            """.trimIndent()
             val actual = subject.compileAndLintWithContext(env, code)
             assertThat(actual).hasSize(1)
         }
@@ -221,7 +221,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     else -> 100
                 }
             }
-            """
+            """.trimIndent()
             val actual = subject.compileAndLintWithContext(env, code)
             assertThat(actual).hasSize(1)
         }
@@ -240,7 +240,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     false -> 2
                 }
             }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
 
@@ -260,7 +260,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                     null -> 100
                 }
             }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
     }
@@ -301,7 +301,7 @@ class ElseCaseInsteadOfExhaustiveWhenSpec(private val env: KotlinCoreEnvironment
                         else -> print("x is funny")
                     }
                 }
-            """
+            """.trimIndent()
             assertThat(subject.compileAndLintWithContext(env, code)).isEmpty()
         }
     }
