@@ -22,7 +22,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     listOf("hello")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -34,7 +34,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOf("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -45,7 +45,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     listOf("hello").isEmpty().not()
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -56,7 +56,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     listOf("hello");println("foo")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -67,7 +67,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     println("foo");listOf("hello")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -78,7 +78,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     listOf("hello")//foo
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -90,7 +90,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo(input: Int) {
                     input.isTheAnswer()
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -110,7 +110,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     var x: List<String>
                     x = listA()
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -123,7 +123,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     noReturnValue()
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -136,7 +136,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     if (returnsBoolean()) {}
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -149,7 +149,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     if (42 == returnsInt()) {}
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -162,7 +162,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     println(returnsInt())
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -175,7 +175,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     println(message = returnsInt())
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -197,16 +197,16 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     println("foo")
                 }
-            """
+            """.trimIndent()
             val annotationClass = """
                 package annotation
 
                 annotation class CheckReturnValue
-            """
+            """.trimIndent()
 
             val findings = subject.lintWithContext(env, code, annotationClass)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(7, 5)
+            assertThat(findings).hasStartSourceLocation(7, 5)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -224,10 +224,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(9, 5)
+            assertThat(findings).hasStartSourceLocation(9, 5)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -245,7 +245,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello").isEmpty().not()
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -269,7 +269,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                         .not()
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -291,10 +291,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                         .listOfChecked()
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(12, 10)
+            assertThat(findings).hasStartSourceLocation(12, 10)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -311,10 +311,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun foo() {
                     listOfChecked("hello");println("foo")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(9, 5)
+            assertThat(findings).hasStartSourceLocation(9, 5)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -332,10 +332,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     println("foo");listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(9, 20)
+            assertThat(findings).hasStartSourceLocation(9, 20)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -353,10 +353,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     /* foo */listOfChecked("hello")//foo
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(9, 14)
+            assertThat(findings).hasStartSourceLocation(9, 14)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -373,10 +373,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     input.isTheAnswer()
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(8, 11)
+            assertThat(findings).hasStartSourceLocation(8, 11)
             assertThat(findings[0]).hasMessage("The call isTheAnswer is returning a value that is ignored.")
         }
 
@@ -395,7 +395,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     x = listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -414,7 +414,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     noReturnValue()
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -432,7 +432,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     if (returnsBoolean()) {}
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -450,7 +450,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     if (42 == returnsInt()) {}
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -468,7 +468,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     println(returnsInt())
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -486,7 +486,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun f() {
                     println(message = returnsInt())
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -506,7 +506,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 } else {
                     returnsInt()
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -527,7 +527,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     returnsInt()
                     2
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
         }
@@ -549,7 +549,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                         returnsInt()
                     }.plus(1)
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -572,7 +572,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                         2
                     }.plus(1)
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
         }
@@ -594,7 +594,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                         returnsInt()
                     }
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
         }
@@ -618,7 +618,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                         .print()
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -638,7 +638,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun main() {
                     Assertions().listOfChecked("hello")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
         }
@@ -658,7 +658,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun main() {
                     Assertions.listOfChecked("hello")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
         }
@@ -680,7 +680,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun main() {
                     Assertions().listOfChecked("hello")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -702,7 +702,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                 fun main() {
                     Parent.Child().listOfChecked("hello")
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -727,10 +727,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(8, 5)
+            assertThat(findings).hasStartSourceLocation(8, 5)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -748,7 +748,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -764,15 +764,15 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
     }
 
     @Nested
-    inner class `restrict to annotated methods config` {
-        val subject = IgnoredReturnValue(TestConfig(mapOf("restrictToAnnotatedMethods" to false)))
+    inner class `restrict to config` {
+        val subject = IgnoredReturnValue(TestConfig(mapOf("restrictToConfig" to false)))
 
         @Test
         fun `reports when a function is annotated with a custom annotation`() {
@@ -788,10 +788,10 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(9, 5)
+            assertThat(findings).hasStartSourceLocation(9, 5)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
@@ -804,13 +804,32 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).hasSize(1)
-            assertThat(findings).hasSourceLocation(4, 5)
+            assertThat(findings).hasStartSourceLocation(4, 5)
             assertThat(findings[0]).hasMessage("The call listOfChecked is returning a value that is ignored.")
         }
 
+        @Test
+        fun `reports when a function returns type that should not be ignored`() {
+            val code = """
+                import kotlinx.coroutines.flow.MutableStateFlow
+
+                fun flowOfChecked(value: String) = MutableStateFlow(value)
+
+                fun foo() : Int {
+                    flowOfChecked("hello")
+                    return 42
+                }
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+            assertThat(findings)
+                .singleElement()
+                .hasSourceLocation(6, 5)
+                .hasMessage("The call flowOfChecked is returning a value that is ignored.")
+        }
+
         @Test
         fun `does not report when a function has _@CanIgnoreReturnValue_`() {
             val code = """
@@ -825,7 +844,7 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
             assertThat(findings).isEmpty()
         }
@@ -844,12 +863,12 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val rule = IgnoredReturnValue(
                 TestConfig(
                     mapOf(
                         "ignoreReturnValueAnnotations" to listOf("*.CustomIgnoreReturn"),
-                        "restrictToAnnotatedMethods" to false
+                        "restrictToConfig" to false
                     )
                 )
             )
@@ -868,12 +887,12 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
                     listOfChecked("hello")
                     return 42
                 }
-            """
+            """.trimIndent()
             val rule = IgnoredReturnValue(
                 TestConfig(
                     mapOf(
                         "ignoreFunctionCall" to listOf("foo.listOfChecked"),
-                        "restrictToAnnotatedMethods" to false
+                        "restrictToConfig" to false
                     )
                 )
             )
@@ -881,4 +900,70 @@ class IgnoredReturnValueSpec(private val env: KotlinCoreEnvironment) {
             assertThat(findings).isEmpty()
         }
     }
+
+    @Nested
+    inner class `return value types default config` {
+        private val subject = IgnoredReturnValue()
+
+        @Test
+        fun `reports when result of function returning Flow is ignored`() {
+            val code = """
+                import kotlinx.coroutines.flow.flowOf
+                
+                fun foo() {
+                    flowOf(1, 2, 3)
+                }
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+
+            assertThat(findings)
+                .singleElement()
+                .hasSourceLocation(line = 4, column = 5)
+                .hasMessage("The call flowOf is returning a value that is ignored.")
+        }
+
+        @Test
+        fun `reports when a function returned result is used in a chain that returns a Flow`() {
+            val code = """
+                import kotlinx.coroutines.flow.*
+                
+                fun foo() {
+                    flowOf(1, 2, 3)
+                        .onEach { println(it) }
+                }
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+
+            assertThat(findings)
+                .singleElement()
+                .hasSourceLocation(line = 5, column = 10)
+                .hasMessage("The call onEach is returning a value that is ignored.")
+        }
+
+        @Test
+        fun `does not report when a function returned value is used to be returned`() {
+            val code = """
+                import kotlinx.coroutines.flow.flowOf
+                
+                fun foo() = flowOf(1, 2, 3)
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+            assertThat(findings).isEmpty()
+        }
+
+        @Test
+        fun `does not report when a function returned value is consumed in a chain that returns an Unit`() {
+            val code = """
+                import kotlinx.coroutines.flow.*
+                
+                suspend fun foo() {
+                    flowOf(1, 2, 3)
+                        .onEach { println(it) }
+                        .collect()
+                }
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+            assertThat(findings).isEmpty()
+        }
+    }
 }
