@@ -9,6 +9,7 @@ import io.gitlab.arturbosch.detekt.api.Issue
 import io.gitlab.arturbosch.detekt.api.Rule
 import io.gitlab.arturbosch.detekt.api.Severity
 import io.gitlab.arturbosch.detekt.api.config
+import io.gitlab.arturbosch.detekt.api.internal.ActiveByDefault
 import io.gitlab.arturbosch.detekt.api.internal.Configuration
 import org.jetbrains.kotlin.psi.KtElement
 import org.jetbrains.kotlin.psi.KtPackageDirective
@@ -16,6 +17,7 @@ import org.jetbrains.kotlin.psi.KtPackageDirective
 /**
  * Reports when the file location does not match the declared package.
  */
+@ActiveByDefault(since = "1.21.0")
 class InvalidPackageDeclaration(config: Config = Config.empty) : Rule(config) {
 
     override val issue = Issue(
