@@ -31,7 +31,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean) : Test
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -45,7 +45,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -60,7 +60,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -83,7 +83,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean?) : Test
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -97,7 +97,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean?) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -112,7 +112,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean?) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -135,7 +135,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean = false) : Test
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -149,7 +149,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean = false) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -164,7 +164,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: Boolean = false) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -180,14 +180,30 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
         }
 
         @Test
-        fun `should not warn about Java Boolean override by default`() {
+        fun `should not warn about Java Boolean override in data class by default`() {
             val code = """
                 interface Test {
                     val default: java.lang.Boolean
                 }
 
                 data class TestImpl (override var default: java.lang.Boolean) : Test
-            """
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+
+            assertThat(findings).hasSize(1)
+        }
+
+        @Test
+        fun `should not warn about Java Boolean override by default`() {
+            val code = """
+                interface Test {
+                    val default: java.lang.Boolean
+                }
+
+                class TestImpl : Test {
+                    override val default: java.lang.Boolean = java.lang.Boolean(true)
+                }
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -201,7 +217,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: java.lang.Boolean) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -216,7 +232,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 }
 
                 data class TestImpl (override var default: java.lang.Boolean) : Test
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -238,6 +254,24 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
 
             assertThat(findings).isEmpty()
         }
+
+        @Test
+        fun `should highlight only the name`() {
+            val code = """
+                data class Test(
+                    /**
+                     * True if the user's e-mail address has been verified; otherwise false.
+                     */
+                    @Deprecated("Don't use this", replaceWith = ReplaceWith("email_verified"))
+                    val emailVerified: Boolean?,
+                )
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+
+            assertThat(findings)
+                .hasSize(1)
+                .hasTextLocations("emailVerified")
+        }
     }
 
     @Nested
@@ -248,7 +282,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var default: Boolean = true
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -264,7 +298,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean = true
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -276,7 +310,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 object Test {
                     const val CONSTANT_VAL_BOOLEAN = true
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(0)
@@ -292,7 +326,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean = true
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -309,7 +343,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean = true
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -322,7 +356,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var default: Boolean? = null
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -338,7 +372,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean? = null
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -354,7 +388,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean? = null
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -371,7 +405,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean? = null
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -384,7 +418,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var default: Boolean = false
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -400,7 +434,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean = false
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -416,7 +450,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean = false
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -433,7 +467,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: Boolean = false
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -446,7 +480,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var default = true
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -462,7 +496,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default = true
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -478,7 +512,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default = true
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -495,7 +529,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default = true
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -508,7 +542,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var default: java.lang.Boolean = java.lang.Boolean(true)
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -524,7 +558,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: java.lang.Boolean = java.lang.Boolean(true)
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).hasSize(1)
@@ -540,7 +574,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: java.lang.Boolean = java.lang.Boolean(true)
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to false))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -557,7 +591,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class TestImpl : Test {
                     override var default: java.lang.Boolean = java.lang.Boolean(true)
                 }
-            """
+            """.trimIndent()
             val config = TestConfig(mapOf(IGNORE_OVERRIDDEN to true))
             val findings = BooleanPropertyNaming(config).compileAndLintWithContext(env, code)
 
@@ -570,7 +604,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var count: Int = 0
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).isEmpty()
@@ -583,7 +617,7 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                     var isEnabled: Boolean = true
                     var hasDefault: Boolean = true
                 }
-            """
+            """.trimIndent()
             val findings = subject.compileAndLintWithContext(env, code)
 
             assertThat(findings).isEmpty()
@@ -595,12 +629,30 @@ class BooleanPropertyNamingSpec(val env: KotlinCoreEnvironment) {
                 class Test {
                     var needReload: Boolean = true
                 }
-            """
+            """.trimIndent()
 
             val config = TestConfig(mapOf(ALLOWED_PATTERN to "^(is|has|are|need)"))
             assertThat(BooleanPropertyNaming(config).compileAndLint(code))
                 .isEmpty()
         }
+
+        @Test
+        fun `should highlight only the name`() {
+            val code = """
+                class Test {
+                    /**
+                     * True if the user's e-mail address has been verified; otherwise false.
+                     */
+                    @Deprecated("Don't use this", replaceWith = ReplaceWith("email_verified"))
+                    var emailVerified: Boolean? = false
+                }
+            """.trimIndent()
+            val findings = subject.compileAndLintWithContext(env, code)
+
+            assertThat(findings)
+                .hasSize(1)
+                .hasTextLocations("emailVerified")
+        }
     }
 }
 
