@@ -1,11 +1,26 @@
 package io.gitlab.arturbosch.detekt.rules.naming
 
+import io.gitlab.arturbosch.detekt.test.TestConfig
 import io.gitlab.arturbosch.detekt.test.assertThat
 import io.gitlab.arturbosch.detekt.test.compileAndLint
 import org.junit.jupiter.api.Test
 
 class EnumNamingSpec {
 
+    @Test
+    fun `should use custom name for enum`() {
+        val rule = EnumNaming(TestConfig(mapOf(EnumNaming.ENUM_PATTERN to "^(enum1)|(enum2)$")))
+        assertThat(
+            rule.compileAndLint(
+                """
+        enum class aBbD {
+            enum1, enum2
+        }
+                """.trimIndent()
+            )
+        ).isEmpty()
+    }
+
     @Test
     fun `should detect no violation`() {
         val findings = EnumNaming().compileAndLint(
@@ -13,7 +28,7 @@ class EnumNamingSpec {
             enum class WorkFlow {
                 ACTIVE, NOT_ACTIVE, Unknown, Number1
             }
-            """
+            """.trimIndent()
         )
         assertThat(findings).isEmpty()
     }
@@ -24,8 +39,8 @@ class EnumNamingSpec {
             enum class WorkFlow {
                 default
             }
-        """
-        assertThat(NamingRules().compileAndLint(code)).hasSize(1)
+        """.trimIndent()
+        assertThat(EnumNaming().compileAndLint(code)).hasSize(1)
     }
 
     @Test
@@ -34,7 +49,7 @@ class EnumNamingSpec {
             enum class WorkFlow {
                 _Default
             }
-        """
+        """.trimIndent()
         assertThat(EnumNaming().compileAndLint(code)).hasSize(1)
     }
 
@@ -44,7 +59,7 @@ class EnumNamingSpec {
             enum class WorkFlow {
                 @Suppress("EnumNaming") _Default
             }
-        """
+        """.trimIndent()
         assertThat(EnumNaming().compileAndLint(code)).isEmpty()
     }
 
@@ -54,7 +69,7 @@ class EnumNamingSpec {
             enum class WorkFlow {
                 _Default,
             }
-        """
+        """.trimIndent()
         val findings = EnumNaming().compileAndLint(code)
         assertThat(findings).hasTextLocations(26 to 34)
     }
