@@ -50,7 +50,7 @@ class MatchingDeclarationNameSpec {
                 enum class E {
                     ONE, TWO, THREE
                 }
-                """,
+                """.trimIndent(),
                 filename = "E.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
@@ -64,7 +64,7 @@ class MatchingDeclarationNameSpec {
                 class C
                 object O
                 fun a() = 5
-                """,
+                """.trimIndent(),
                 filename = "MultiDeclarations.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
@@ -78,7 +78,7 @@ class MatchingDeclarationNameSpec {
                 class C
                 fun a() = 5
                 fun C.b() = 5
-                """,
+                """.trimIndent(),
                 filename = "C.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
@@ -92,7 +92,7 @@ class MatchingDeclarationNameSpec {
                 fun a() = 5
                 fun C.b() = 5
                 class C
-                """,
+                """.trimIndent(),
                 filename = "Classes.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
@@ -105,7 +105,7 @@ class MatchingDeclarationNameSpec {
                 """
             private class C
             fun a() = 5
-                """,
+                """.trimIndent(),
                 filename = "b.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
@@ -118,7 +118,7 @@ class MatchingDeclarationNameSpec {
             typealias Foo = FooImpl
 
             class FooImpl {}
-            """
+            """.trimIndent()
             val ktFile = compileContentForTest(code, filename = "Foo.kt")
             val findings = MatchingDeclarationName().lint(ktFile)
             assertThat(findings).isEmpty()
@@ -132,7 +132,7 @@ class MatchingDeclarationNameSpec {
         fun `should not pass for object declaration`() {
             val ktFile = compileContentForTest("object O", filename = "Objects.kt")
             val findings = MatchingDeclarationName().lint(ktFile)
-            assertThat(findings).hasSourceLocation(1, 8)
+            assertThat(findings).hasStartSourceLocation(1, 8)
         }
 
         @Test
@@ -142,49 +142,49 @@ class MatchingDeclarationNameSpec {
                 filename = "Objects.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
-            assertThat(findings).hasSourceLocation(1, 45)
+            assertThat(findings).hasStartSourceLocation(1, 45)
         }
 
         @Test
         fun `should not pass for class declaration`() {
             val ktFile = compileContentForTest("class C", filename = "Classes.kt")
             val findings = MatchingDeclarationName().lint(ktFile)
-            assertThat(findings).hasSourceLocation(1, 7)
+            assertThat(findings).hasStartSourceLocation(1, 7)
         }
 
         @Test
         fun `should not pass for class declaration as first declaration with utility functions`() {
             val ktFile = compileContentForTest(
                 """
-                class C
-                fun a() = 5
-                fun C.b() = 5
+                    class C
+                    fun a() = 5
+                    fun C.b() = 5
                 """.trimIndent(),
                 filename = "ClassUtils.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
-            assertThat(findings).hasSourceLocation(1, 7)
+            assertThat(findings).hasStartSourceLocation(1, 7)
         }
 
         @Test
         fun `should not pass for interface declaration`() {
             val ktFile = compileContentForTest("interface I", filename = "Not_I.kt")
             val findings = MatchingDeclarationName().lint(ktFile)
-            assertThat(findings).hasSourceLocation(1, 11)
+            assertThat(findings).hasStartSourceLocation(1, 11)
         }
 
         @Test
         fun `should not pass for enum declaration`() {
             val ktFile = compileContentForTest(
                 """
-                enum class NOT_E {
-                    ONE, TWO, THREE
-                }
+                    enum class NOT_E {
+                        ONE, TWO, THREE
+                    }
                 """.trimIndent(),
                 filename = "E.kt"
             )
             val findings = MatchingDeclarationName().lint(ktFile)
-            assertThat(findings).hasSourceLocation(1, 12)
+            assertThat(findings).hasStartSourceLocation(1, 12)
         }
 
         @Test
@@ -192,7 +192,7 @@ class MatchingDeclarationNameSpec {
             val code = """
                 class FooImpl {}
                 typealias Bar = FooImpl
-            """
+            """.trimIndent()
             val ktFile = compileContentForTest(code, filename = "Foo.kt")
             val findings = MatchingDeclarationName().lint(ktFile)
             assertThat(findings).hasSize(1)
@@ -202,16 +202,16 @@ class MatchingDeclarationNameSpec {
         fun `should not pass for class declaration not as first declaration with utility functions when mustBeFirst is false`() {
             val ktFile = compileContentForTest(
                 """
-                fun a() = 5
-                fun C.b() = 5
-                class C
+                    fun a() = 5
+                    fun C.b() = 5
+                    class C
                 """.trimIndent(),
                 filename = "Classes.kt"
             )
             val findings = MatchingDeclarationName(
                 TestConfig("mustBeFirst" to "false")
             ).lint(ktFile)
-            assertThat(findings).hasSourceLocation(3, 7)
+            assertThat(findings).hasStartSourceLocation(3, 7)
         }
     }
 }
