@@ -1,11 +1,18 @@
 package io.gitlab.arturbosch.detekt.rules.naming
 
+import io.gitlab.arturbosch.detekt.test.TestConfig
 import io.gitlab.arturbosch.detekt.test.compileAndLint
 import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.Test
 
 class PackageNamingSpec {
 
+    @Test
+    fun `should use custom name for package`() {
+        val rule = PackageNaming(TestConfig(PackageNaming.PACKAGE_PATTERN to "^(package_1)$"))
+        assertThat(rule.compileAndLint("package package_1")).isEmpty()
+    }
+
     @Test
     fun `should ignore the issue by alias suppression`() {
         assertThat(
@@ -13,7 +20,7 @@ class PackageNamingSpec {
                 """
                 @file:Suppress("PackageDirectoryMismatch")
                 package FOO.BAR
-                """
+                """.trimIndent()
             )
         ).isEmpty()
     }
