@@ -44,6 +44,7 @@ import org.jetbrains.kotlin.types.typeUtil.isInterface
  * }
  * </noncompliant>
  */
+@Suppress("ViolatesTypeResolutionRequirements")
 @ActiveByDefault(since = "1.2.0")
 class UnnecessaryAbstractClass(config: Config = Config.empty) : Rule(config) {
 
@@ -54,9 +55,7 @@ class UnnecessaryAbstractClass(config: Config = Config.empty) : Rule(config) {
         Issue(
             "UnnecessaryAbstractClass",
             Severity.Style,
-            "An abstract class is unnecessary and can be refactored. " +
-                "An abstract class should have both abstract and concrete properties or functions. " +
-                noConcreteMember + " " + noAbstractMember,
+            "An abstract class is unnecessary. May be refactored to an interface or to a concrete class.",
             Debt.FIVE_MINS
         )
 
