@@ -23,7 +23,6 @@ import org.jetbrains.kotlin.psi.KtSafeQualifiedExpression
 import org.jetbrains.kotlin.psi.KtSimpleNameExpression
 import org.jetbrains.kotlin.psi.psiUtil.collectDescendantsOfType
 import org.jetbrains.kotlin.resolve.BindingContext
-import org.jetbrains.kotlin.resolve.calls.util.getResolvedCall
 
 /**
  * `let` expressions are used extensively in our code for null-checking and chaining functions,
@@ -60,8 +59,6 @@ class UnnecessaryLet(config: Config) : Rule(config) {
     override fun visitCallExpression(expression: KtCallExpression) {
         super.visitCallExpression(expression)
 
-        if (bindingContext == BindingContext.EMPTY) return
-
         if (!expression.isLetExpr()) return
 
         val lambdaExpr = expression.firstLambdaArg
@@ -124,7 +121,7 @@ private fun KtBlockExpression.hasOnlyOneStatement() = this.children.size == 1
 
 private fun PsiElement.countVarRefs(parameter: CallableDescriptor, context: BindingContext): Int =
     collectDescendantsOfType<KtSimpleNameExpression> {
-        it.getResolvedCall(context)?.resultingDescriptor == parameter
+        context[BindingContext.REFERENCE_TARGET, it] == parameter
     }.count()
 
 private fun KtLambdaExpression.countReferences(context: BindingContext): Int {
