@@ -39,6 +39,7 @@ import org.jetbrains.kotlin.psi.KtProperty
 import org.jetbrains.kotlin.psi.KtPropertyDelegate
 import org.jetbrains.kotlin.psi.KtReferenceExpression
 import org.jetbrains.kotlin.psi.KtSecondaryConstructor
+import org.jetbrains.kotlin.psi.KtValueArgumentName
 import org.jetbrains.kotlin.psi.psiUtil.containingClassOrObject
 import org.jetbrains.kotlin.psi.psiUtil.getStrictParentOfType
 import org.jetbrains.kotlin.psi.psiUtil.isPrivate
@@ -55,6 +56,7 @@ private const val ARRAY_GET_METHOD_NAME = "get"
  * If these private elements are unused they should be removed. Otherwise, this dead code
  * can lead to confusion and potential bugs.
  */
+@Suppress("ViolatesTypeResolutionRequirements")
 @ActiveByDefault(since = "1.16.0")
 class UnusedPrivateMember(config: Config = Config.empty) : Rule(config) {
 
@@ -130,7 +132,9 @@ private class UnusedFunctionVisitor(
                                 listOf(KtTokens.IN_KEYWORD, KtTokens.NOT_IN).flatMap {
                                     functionReferences[it.value].orEmpty()
                                 }
-                            } else emptyList()
+                            } else {
+                                emptyList()
+                            }
                             directReferences + assignmentReferences + containingReferences
                         } else {
                             emptyList()
@@ -258,7 +262,9 @@ private class UnusedParameterVisitor(allowedNames: Regex) : UnusedMemberVisitor(
             }
 
             override fun visitReferenceExpression(expression: KtReferenceExpression) {
-                parameters.remove(expression.text)
+                if (expression.parent !is KtValueArgumentName) {
+                    parameters.remove(expression.text.removeSurrounding("`"))
+                }
                 super.visitReferenceExpression(expression)
             }
         })
