@@ -18,7 +18,6 @@ import org.jetbrains.kotlin.psi.KtCallExpression
 import org.jetbrains.kotlin.psi.KtExpression
 import org.jetbrains.kotlin.psi.KtStringTemplateExpression
 import org.jetbrains.kotlin.psi2ir.deparenthesize
-import org.jetbrains.kotlin.resolve.BindingContext
 import org.jetbrains.kotlin.resolve.calls.util.getResolvedCall
 import org.jetbrains.kotlin.resolve.calls.util.getType
 import org.jetbrains.kotlin.resolve.descriptorUtil.fqNameOrNull
@@ -57,7 +56,6 @@ class UseOrEmpty(config: Config = Config.empty) : Rule(config) {
     @Suppress("ReturnCount")
     override fun visitBinaryExpression(expression: KtBinaryExpression) {
         super.visitBinaryExpression(expression)
-        if (bindingContext == BindingContext.EMPTY) return
 
         if (expression.operationToken != KtTokens.ELVIS) return
         val left = expression.left ?: return
@@ -71,7 +69,9 @@ class UseOrEmpty(config: Config = Config.empty) : Rule(config) {
             if (functionDescriptor != null &&
                 functionDescriptor.isOperator &&
                 functionDescriptor.typeParameters.isNotEmpty()
-            ) return
+            ) {
+                return
+            }
         }
 
         val rightType = right.getType(bindingContext) ?: return
