@@ -21,7 +21,7 @@ class DataClassContainsFunctionsSpec {
                     fun toConversion() = C(i.toString())
                 }
             }
-        """
+        """.trimIndent()
 
         @Test
         fun `reports valid data class with conversion function`() {
@@ -29,11 +29,18 @@ class DataClassContainsFunctionsSpec {
         }
 
         @Test
-        fun `reports valid data class without conversion function`() {
+        fun `reports valid data class without conversion function string`() {
             val config = TestConfig(mapOf(CONVERSION_FUNCTION_PREFIX to ""))
             val rule = DataClassContainsFunctions(config)
             assertThat(rule.compileAndLint(code)).hasSize(2)
         }
+
+        @Test
+        fun `reports valid data class without conversion function list`() {
+            val config = TestConfig(mapOf(CONVERSION_FUNCTION_PREFIX to emptyList<String>()))
+            val rule = DataClassContainsFunctions(config)
+            assertThat(rule.compileAndLint(code)).hasSize(2)
+        }
     }
 
     @Test
@@ -48,7 +55,7 @@ class DataClassContainsFunctionsSpec {
             class C {
                 fun f() {}
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 
@@ -69,7 +76,7 @@ class DataClassContainsFunctionsSpec {
                     return super.toString()
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 }
